%global momorel 28

Summary: The Linux kernel (the core of the Linux operating system)


# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up      %{?_without_up:      0} %{?!_without_up:      1}
# kernel-smp (only valid for ppc 32-bit, sparc64)
%define with_smp     %{?_without_smp:     0} %{?!_without_smp:     1}
# kernel-PAE (only valid for i686)
%define with_pae     %{?_without_pae:     0} %{?!_without_pae:     1}
# kernel-xen
%define with_xen     %{?_without_xen:     0} %{?!_without_xen:     1}
# kernel-kdump
%define with_kdump   %{?_without_kdump:   0} %{?!_without_kdump:   1}
# kernel-debug
%define with_debug   %{?_without_debug:   0} %{!?_without_debug:   1}
# kernel-doc
%define with_doc     %{?_without_doc:     0} %{?!_without_doc:     1}
# kernel-headers
%define with_headers %{?_without_headers: 0} %{?!_without_headers: 1}

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly %{?_with_baseonly: 1} %{?!_with_baseonly: 0}
# Only build the smp kernel (--with smponly):
%define with_smponly  %{?_with_smponly:  1} %{?!_with_smponly:  0}
# Only build the xen kernel (--with xenonly):
%define with_xenonly  %{?_with_xenonly:  1} %{?!_with_xenonly:  0}

# Whether or not to gpg sign modules
%define with_modsign 1

# Whether or not to do C=1 builds with sparse
%define usesparse 0

# Whether or not to apply the Xen patches -- leave this enabled
%define includexen 0
# Xen doesn't work with current upstream kernel, shut it off
%define with_xen 0

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
%define debugbuildsenabled 1

# [swsusp2]
%global with_swsusp2       0
# [usagi_ipv6]
%global with_usagi_ipv6    0
# [kdb]
%global with_kdb           0
%global kdb_ver            v4.4
%global kdb_kernel_ver     2.6.21
# [unionfs]
%global with_unionfs       1
%global unionfs_ver        2.6.21.6
# [btrfs]
%global with_btrfs         1 
%global btrfs_ver          0.7 
# [madwifi]
%global with_madwifi       1
%global madwifi_snap_use   0
%global madwifi_stable_ver 0.9.30.13
%global madwifi_snap_ver   ng-r2250-20070401
# [ivtv]
%global with_ivtv          1
%global ivtv_ver           0.10.5
# [ipw3945]
%global with_ipw3945       0
%global ipw3945_kmod_ver   1.2.1
# [nilfs]
%global with_nilfs         1
%global nilfs_ver          2.0.0-testing-3
# [nvidia]
%global with_nvidia        1

# Build with source extension patch
%global build_ext 1
%global patchlevel 7

# Build with kernel rc patch
%global build_rc 0
%global rc_ver 7

# Build with kernel snapshot patch
%global build_git 0
%global git_ver 0
# Is there exclusive choice with build_git and build_rc?

%if %{build_ext}
%global kversion_ext %{kversion}.%{patchlevel}
%endif

%if %{build_rc}
%global kversion_rc %{kversion}-rc%{rc_ver}
%global release 0.%{rc_ver}.%{momorel}m
%endif

%if %{build_git}
%global kversion_git %{kversion}-git%{git_ver}
%global release %{git_ver}.%{momorel}m
%if %{build_rc}
%global release git%{git_ver}-%{momorel}m
%endif
%endif

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
#% define buildid .local
%global sublevel 21
%global kversion 2.6.%{sublevel}
%global rpmversion 2.6.%{sublevel}
%global release %{momorel}m%{?dist}

%define make_target bzImage
%define kernel_image x86

%define xen_hv_cset 11633
%define xen_flags verbose=y crash_debug=y
%define xen_target vmlinuz
%define xen_image vmlinuz

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
%define hdrarch %_target_cpu

# if requested, only build base kernel
%if %{with_baseonly}
%define with_smp 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build xen kernel
%if %{with_xenonly}
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debug 0
%endif

# don't build xen or kdump kernels for OLPC
%if 0%{?olpc}
%define with_xen 0
%define with_kdump 0
%endif

# if building for RHEL
%if 0%{?rhel}
# don't build i586 RHEL kernels
%define all_x86 i386 i686
# RHEL has not-yet-upstream relocatable x86_64
%ifarch x86_64
%define with_kdump 0
%endif
# if building for Fedora
%else
%define all_x86 i386 i586 i686
%endif

# Overrides for generic default options

# only ppc and sparc64 need separate smp kernels
%ifnarch ppc sparc64 alphaev56
%define with_smp 0
%endif

# pae is only valid on i686
%ifnarch i686
%define with_pae 0
%endif

# xen only builds on i686, x86_64 and ia64
%ifnarch i686 x86_64 ia64
%define with_xen 0
%endif

# only build kernel-kdump on x86_64 and ppc64
# (no relocatable kernel support upstream yet)
%ifnarch x86_64 ppc64 ppc64iseries
%define with_kdump 0
%endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif

## only package docs noarch
#%%ifnarch noarch
#%%define with_doc 0
#%%endif

## no need to build headers again for these arches,
## they can just use i386 and ppc64 headers
#%%ifarch i586 i686 ppc64iseries
#%%define with_headers 0
#%%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-*.config
%endif

# don't sign modules on these platforms
%ifarch s390 s390x sparc sparc64 ppc alpha
%define with_modsign 0
%endif

# sparse blows up on ppc64
%ifarch ppc64 ppc alpha
%define usesparse 0
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%define image_install_path boot
%define hdrarch i386
# we build always xen i686 HV with pae
%define xen_flags verbose=y crash_debug=y pae=y
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%endif

%ifarch ppc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch s390
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch s390x
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%define hdrarch s390
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%define make_target image
%define kernel_image image
%endif

%ifarch sparc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%define make_target image
%define kernel_image image
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define make_target compressed
%define kernel_image vmlinux.gz
# ia64 xen HV doesn't building with debug=y at the moment
%define xen_flags verbose=y crash_debug=y
%define xen_target compressed
%define xen_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-alpha*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386 or s390x -- we only do kernel-headers there.
%define nobuildarches i386 s390

%ifarch %nobuildarches
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.9-3m

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
%if 0%{?olpc}
ExclusiveArch: i386 i586
%else
# DO NOT CHANGE THIS LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390 s390x alpha alphaev56
%endif
ExclusiveOS: Linux
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes


#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils
%if %{with_modsign}
BuildPreReq: gnupg
%endif
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildRequires: sparse >= 0.3
BuildConflicts: rhbuildsys(DiskFree) < 500Mb


Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2
NoSource: 0
#Source1: xen-%{xen_hv_cset}.tar.bz2
Source2: Config.mk

Source10: COPYING.modules
Source11: genkey
Source12: kabitool
Source14: find-provides
Source15: merge.pl

Source20: kernel-%{kversion}-i586.config
Source21: kernel-%{kversion}-i686.config
Source22: kernel-%{kversion}-i686-debug.config
Source23: kernel-%{kversion}-i686-PAE.config
Source24: kernel-%{kversion}-i686-PAE-debug.config

Source25: kernel-%{kversion}-x86_64.config
Source26: kernel-%{kversion}-x86_64-debug.config
Source27: kernel-%{kversion}-x86_64-kdump.config

Source28: kernel-%{kversion}-ppc.config
Source29: kernel-%{kversion}-ppc-smp.config
Source30: kernel-%{kversion}-ppc64.config
Source31: kernel-%{kversion}-ppc64-kdump.config

Source34: kernel-%{kversion}-s390.config
Source35: kernel-%{kversion}-s390x.config

Source36: kernel-%{kversion}-ia64.config

Source37: kernel-%{kversion}-i686-xen.config
Source38: kernel-%{kversion}-x86_64-xen.config
Source39: kernel-%{kversion}-ia64-xen.config

#Source50: kernel-%{kversion}-sparc.config
#Source51: kernel-%{kversion}-sparc64.config
#Source52: kernel-%{kversion}-sparc64-smp.config

#Source60: kernel-%{kversion}-alpha.config
#Source61: kernel-%{kversion}-alphaev56.config
#Source62: kernel-%{kversion}-alphaev56-smp.config

# Source80: config-rhel-generic
# Source81: config-rhel-x86-generic
# Source82: config-olpc-generic

# Momonga logo
Source100: logo_momonga_mono.pbm
Source101: logo_momonga_vga16.ppm
Source102: logo_momonga_gray256.pgm
Source103: logo_momonga_clut224.ppm
Source104: logo_spu_clut224-momonga.ppm

##### driver for TC9020 32bit PCI 10/100/1000Mbps Ethernet MAC Controller
# http://www.tmi.com.tw/pp-TC9020.html
Source500: http://www.tmi.com.tw/Data/driver/TC902X_Linux.zip

## madwifi driver
%if %{with_madwifi}
%if %{madwifi_snap_use}
Source2400: http://snapshots.madwifi.org/madwifi-ng-current.tar.gz
%else
Source2400: http://snapshots.madwifi.org/madwifi-hal-%{madwifi_stable_ver}-current.tar.gz
%endif
NoSource: 2400
%endif

## ipw3945 driver
%if %{with_ipw3945}
# from http://downloadfinder.intel.com/scripts-df-external/Detail_Desc.aspx?agr=Y&Inst=Yes&ProductID=2259&DwnldID=10315&strOSs=39&OSFullName=Linux*&lang=eng
Source2450: http://dl.sourceforge.net/sourceforge/ipw3945/ipw3945-%{ipw3945_kmod_ver}.tgz
NoSource: 2450
%endif

## nilfs
%if %{with_nilfs}
Source2600: http://www.nilfs.org/download/nilfs-%{nilfs_ver}.tar.bz2
NoSource: 2600
%endif

## btrfs
%if %{with_btrfs}
Source2650: http://oss.oracle.com/projects/btrfs/dist/files/btrfs-%{btrfs_ver}.tar.bz2
NoSource: 2650
%endif

## ivtv
%if %{with_ivtv}
Source2700: http://dl.ivtvdriver.org/ivtv/archive/0.10.x/ivtv-%{ivtv_ver}.tar.gz
NoSource: 2700
%endif

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
%if %{build_rc}
%global md5patch0 3a54bf5a7cf6b124e680e1d08fe1b20b
%NoPatch 0  http://www.kernel.org/pub/linux/kernel/v2.6/testing/patch-%{kversion_rc}.bz2 %{md5patch0}
%endif

%if %{build_ext}
%global md5patch1 b9c8734471a454806c77f040fcf9869b
%NoPatch 1 http://www.kernel.org/pub/linux/kernel/v2.6/patch-%{kversion_ext}.bz2 %{md5patch1}
%endif

%if %{build_git}
%global md5patch2 068d11308bec05f04df3e34f40134a6f
%NoPatch 2 http://www.kernel.org/pub/linux/kernel/v2.6/snapshots/patch-%{srcversion}-git%{git_ver}.bz2 %{md5patch2}
%endif

Patch3: stable-reverts.patch
Patch7:	sched-cfs-v2.6.21.7-v19.patch

# Patches 10 through 99 are for things that are going upstream really soon.
#Patch10: http://people.redhat.com/roland/utrace/2.6-current/linux-2.6.21-utrace.patch
#Patch10: linux-2.6-utrace.patch
Patch10: linux-2.6.21-utrace.mo.patch
Patch11: nouveau-drm.patch

Patch12: linux-2.6-fix-pmops-1.patch
Patch13: linux-2.6-fix-pmops-2.patch
Patch14: linux-2.6-fix-pmops-3.patch
Patch15: linux-2.6-fix-pmops-4.patch

# enable sysrq-c on all kernels, not only kexec
# FIXME: upstream soon? When? It's been here for ages.
Patch16: linux-2.6-sysrq-c.patch

# DRM bits for 965
Patch17: linux-2.6-i965gm-support.patch

# backport DRM
Patch24: drm-backport1.patch
Patch25: drm-backport2.patch
Patch26: drm-backport3.patch
Patch27: drm-backport4.patch

# backport AGPGART
Patch29: agpgart-backport.patch

#SWSUP2
# Web: http://swsusp.sf.net/
#      http://softwaresuspend.berlios.de/wiki/KnownIssues
# ML : http://lists.berlios.de/pipermail/softwaresuspend-devel/2004-December/
# URL: http://www.suspend2.net/downloads/all/
#      (ex:  software-suspend-2.1.9.9-for-2.6.12.tar.bz2)
#                          (swsusp2ver) (swsusp2kver)
%global swsusp2ver 2.2.9.16
%global swsusp2kver 2.6.21
%global swsusp2name suspend2-%{swsusp2ver}-for-%{swsusp2kver}
Patch48: http://www.suspend2.net/downloads/all/%{swsusp2name}.patch.bz2
NoPatch: 48

## ipv6 subsystem update
# %global md5patch50 4a89f94e5d676249287bf57e55fe4ed6
# Patch50: %{usagiuri}/%{usagisnapver_month}/%{usagipatchname}
# NoPatch: 50
%if %{usagi_ipv6}
Patch50: %{usagipatchname}
%endif

# kdb
Patch70: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-common-2.bz2
Patch71: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-i386-2.bz2
Patch72: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-ia64-1.bz2
Patch73: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-x86_64-2.bz2

# SWSUSP2
Patch92: linux-2.6.9-swsusp-smp2.patch

# Patches 100 through 500 are meant for architecture patches

# 200 - 299   x86(-64)

Patch200: linux-2.6-x86-tune-generic.patch
Patch201: linux-2.6-x86-vga-vidfail.patch
Patch202: linux-2.6-x86-64-edac-support.patch
Patch203: linux-2.6-x86_64-silence-up-apic-errors.patch
Patch204: linux-2.6-x86-dont-delete-cpu_devs-data.patch
Patch206: linux-2.6-x86-fsc-interrupt-controller-quirk.patch
Patch207: linux-2.6-x86-dell-hpet.patch
Patch209: linux-2.6-x86-64_pmtrace.patch

# 300 - 399   ppc(64)
Patch300: linux-2.6-g5-therm-shutdown.patch
Patch301: linux-2.6-powerpc-slabalign.patch
Patch303: linux-2.6-ppc32-ucmpdi2.patch
Patch304: linux-2.6-ibmvscsi-schizo.patch
Patch305: linux-2.6-pmac-zilog.patch
Patch306: linux-2.6-powerpc-reserve-initrd-1.patch
Patch307: linux-2.6-powerpc-reserve-initrd-2.patch
Patch308: linux-2.6-cell-spu-device-tree.patch
Patch309: linux-2.6-cell-spufs-fixes.patch

Patch310: linux-2.6-common-uevent.patch
Patch311: linux-2.6-uevent-macio.patch
Patch312: linux-2.6-uevent-of_platform.patch
Patch313: linux-2.6-uevent-ebus.patch

Patch330: linux-2.6-powermac-generic-suspend-1.patch
Patch331: linux-2.6-powermac-generic-suspend-2.patch
Patch332: linux-2.6-powermac-generic-suspend-3.patch
Patch333: linux-2.6-powermac-generic-suspend-4.patch

Patch340: linux-2.6-mpc52xx-sdma.patch
Patch341: linux-2.6-mpc52xx-fec.patch

# Patches from ps3-linux-patches.git (2007-05-04)
Patch350: linux-2.6-ps3-stable-patches.patch
Patch351: linux-2.6-ps3-smp-boot.patch
Patch352: linux-2.6-ps3-system-bus-rework.patch
Patch353: linux-2.6-ps3-kexec.patch
Patch354: linux-2.6-ps3-gelic.patch
Patch355: linux-2.6-ps3-gelic-wireless.patch
Patch356: linux-2.6-ps3-ehci-iso.patch
Patch357: linux-2.6-ps3-clear-spu-irq.patch
Patch358: linux-2.6-ps3-wrap-spu-runctl.patch
# Ignore the SPE logo bits. Cute, but not exactly necessary
Patch359: linux-2.6-ps3-storage.patch
Patch360: linux-2.6-ps3-sound.patch
Patch361: linux-2.6-ps3-device-init.patch
Patch362: linux-2.6-ps3-system-bus-rework-2.patch


# And then some minor tweaks...
Patch370: linux-2.6-ps3-memory-probe.patch
Patch371: linux-2.6-ps3-legacy-ioport.patch
Patch372: linux-2.6-ps3fb-panic.patch
Patch373: linux-2.6-ps3-ethernet-modular.patch
Patch374: linux-2.6-ps3-sound-autoload.patch
Patch375: linux-2.6-ps3-ethernet-autoload.patch
Patch376: linux-2.6-ps3av-export-header.patch
Patch377: linux-2.6-ps3-usb-autoload.patch

Patch399: linux-2.6-ps3-append-logo.patch

# 500 - 599   s390(x)

# 600 - 699   sparc(64)

# 700 - 799   alpha

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch800: linux-2.6-build-nonintconfig.patch

# Exec-shield.
Patch810: linux-2.6-execshield.patch

# Module signing infrastructure.
Patch900: linux-2.6-modsign-mpilib.patch
Patch901: linux-2.6-modsign-crypto.patch
Patch902: linux-2.6-modsign-include.patch
Patch903: linux-2.6-modsign-verify.patch
Patch904: linux-2.6-modsign-ksign.patch
Patch905: linux-2.6-modsign-core.patch
Patch906: linux-2.6-modsign-script.patch

# Tux http accelerator.
Patch910: linux-2.6-tux.patch

# 950 - 999 Xen
Patch950: linux-2.6-xen.patch
Patch951: linux-2.6-xen-utrace.patch
Patch952: linux-2.6-xen-x86_64-silence-up-apic-errors.patch
Patch953: linux-2.6-xen-x86_64-add-ppoll-pselect.patch
Patch954: linux-2.6-xen-execshield.patch
Patch955: linux-2.6-xen-tux.patch
Patch956: linux-2.6-xen-execshield-lazy-exec-limit.patch
Patch958: linux-2.6-ia64-kexec-kdump-xen-conflict.patch
Patch960: linux-2.6-xen-blktap-fixes.patch
Patch961: linux-2.6-xen-blktap-cleanup.patch
Patch962: linux-2.6-xen-blktap-dynamic-major.patch
Patch963: linux-2.6-xen-blktap-sysfs.patch
Patch990: linux-2.6-xen-pvfb.patch

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1010: linux-2.6-debug-sizeof-structs.patch
Patch1011: linux-2.6-debug-slab-backtrace.patch
Patch1012: linux-2.6-debug-nmi-timeout.patch
Patch1013: linux-2.6-debug-taint-vm.patch
Patch1015: linux-2.6-debug-spinlock-taint.patch
Patch1016: linux-2.6-debug-extra-warnings.patch
Patch1018: linux-2.6-debug-sleep-in-irq-warning.patch
Patch1019: linux-2.6-debug-must_check.patch
Patch1020: linux-2.6-debug-no-quiet.patch
Patch1021: linux-2.6-debug-boot-delay.patch
Patch1022: linux-2.6-debug-sysfs-crash-debugging.patch
Patch1023: linux-2.6-debug-sysfs-crash-debugging-xen.patch

# Restrict /dev/mem usage.
Patch1050: linux-2.6-devmem.patch
Patch1051: linux-2.6-devmem-xen.patch

# Provide read only /dev/crash driver.
Patch1060: linux-2.6-crash-driver.patch
Patch1061: linux-2.6-crash-driver-xen.patch

Patch1070: linux-2.6-sleepon.patch

# SCSI bits.
Patch1100: linux-2.6-scsi-bounce-isa.patch
Patch1101: linux-2.6-scsi-cpqarray-set-master.patch

# NFS bits.
Patch1201: linux-2.6-NFSD-badness.patch

# NIC driver fixes
Patch1300: linux-2.6-net-e1000-no-msi-warning.patch

# Filesystem stuff.
# Squashfs
#Patch1400: linux-2.6-squashfs.patch
# squashfs3.2-r2
# http://jaist.dl.sourceforge.net/sourceforge/squashfs/squashfs3.0.tar.gz
# Patch1400: squashfs3.2-r2.tar.gz
Patch1400: squashfs3.2-patch.bz2
# GFS2
Patch1410: linux-2.6-gfs2-update.patch
# Reiser4
%global md5patch1410 67e576fb27d45303cb28091d11e71ff7
%NoPatch 1420 http://ftp.namesys.com/pub/reiser4-for-2.6/%{kversion}/reiser4-for-%{kversion}.patch.gz %{md5patch1410}
# ReiserFS
Patch1430: reiserfs-possible-null-pointer-dereference.patch
# unionfs
%if %{with_unionfs}
Patch1440: ftp://ftp.fsl.cs.sunysb.edu/pub/unionfs/unionfs-2.1/unionfs-2.1_for_%{unionfs_ver}.diff.gz
%endif
# XFS
Patch1450: xfs-backport.patch

# Networking core.
Patch1500: linux-2.6-net-silence-noisy-printks.patch

# Misc bits.
Patch1600: linux-2.6-module_version.patch
Patch1601: linux-2.6-sha_alignment.patch
Patch1610: linux-2.6-input-kill-stupid-messages.patch
Patch1620: linux-2.6-ondemand-timer.patch
Patch1630: linux-2.6-kvm-21.patch
Patch1631: linux-2.6-amd-disabled-svm-detect.patch
Patch1632: linux-2.6-amd-disabled-svm-detect-msr-1.patch
Patch1633: linux-2.6-kvm-reinit-real-mode-tss.patch
Patch1640: linux-2.6-module-override-modparam-cmdline.patch
Patch1650: linux-2.6-serial-460800.patch
Patch1660: linux-2.6-mm-udf-fixes.patch
Patch1661: linux-2.6-udf-2.6.22-rc2-1-udf_data_corruption.patch
Patch1662: linux-2.6-udf-2.6.22-rc2-2-udf_block_leak.patch
Patch1670: linux-2.6-sysfs-inode-allocator-oops.patch
Patch1681: linux-2.6-xfs-umount-fix.patch
Patch1690: linux-2.6-PT_LOAD-align.patch
Patch1700: linux-2.6-dvb-spinlock.patch
Patch1710: linux-2.6-nfs-noreaddirplus.patch
Patch1711: linux-2.6-nfs-missing-braces.patch
Patch1720: linux-2.6-proc-self-maps-fix.patch
Patch1730: linux-2.6-suspend-ordering.patch
Patch1740: linux-2.6-softlockup-disable.patch
Patch1770: linux-2.6-optimise-spinlock-debug.patch
Patch1771: linux-2.6-silence-noise.patch
Patch1781: linux-2.6-softirq-printout-irq-trace-events.patch
Patch1791: linux-2.6-libertas.diff
Patch1792: linux-2.6-olpc-touchpad.diff
Patch1793: linux-2.6-raid-autorun.patch
Patch1794: linux-2.6-i82875-edac-pci-setup.patch
Patch1795: linux-2.6-crap-sysfs-workaround.patch

# SELinux/audit patches.
Patch1801: linux-2.6-selinux-mprotect-checks.patch

# Warn about usage of various obsolete functionality that may go away.
Patch1900: linux-2.6-obsolete-oss-warning.patch

# no external module should use these symbols.
Patch1910: linux-2.6-unexport-symbols.patch

# VM bits.
Patch2000: linux-2.6-vm-invalidate_mapping_pages-cond-resched.patch
Patch2001: linux-2.6-vm-silence-atomic-alloc-failures.patch

# Tweak some defaults.
Patch2100: linux-2.6-defaults-fat-utf8.patch
Patch2103: linux-2.6-defaults-unicode-vt.patch
Patch2105: linux-2.6-defaults-nonmi.patch
Patch2106: linux-2.6-defaults-pci_no_msi_mmconf.patch

# ATA Bits
Patch2200: linux-2.6-sata-promise-pata-ports.patch
Patch2201: linux-2.6-libata-hpa.patch
Patch2202: linux-2.6-libata-sata_nv-adma.patch
Patch2203: linux-2.6-libata-ali-atapi-dma.patch
Patch2204: linux-2.6-ata-quirk.patch
Patch2206: linux-2.6-libata-sata_nv-wildcard-removal.patch
Patch2207: linux-2.6-libata-pata-pcmcia-new-ident.patch
Patch2208: linux-2.6-libata-atiixp-ids.patch
Patch2209: linux-2.6-libata-pata-hpt3x2n-correct-revision-boundary.patch
Patch2210: linux-2.6-libata-pata-sis-fix-timing.patch
Patch2211: linux-2.6-libata-setxfer.patch
Patch2212: linux-2.6-libata_ali_max_dma_speed.patch
Patch2213: linux-2.6-ata-use-pio-for-non-16-byte-xfers.patch
Patch2214: linux-2.6-ata-call-check-dma-with-qc-prepared.patch
Patch2215: linux-2.6-libata-ich8m-add-pciid.patch

# ATA spindown
Patch2220: linux-2.6-2110_scsi-sd-printing.patch
Patch2221: linux-2.6-2111_sd-start-stop.patch
Patch2222: linux-2.6-2112_libata-suspend.patch
Patch2223: linux-2.6-2113_libata-spindown-compat.patch
Patch2224: linux-2.6-2114_libata-shutdown-warning.patch
Patch2225: linux-2.6-2115_libata-spindown-status.patch
Patch2226: linux-2.6-2116_libata-remove-spindown-compat.patch
Patch2227: linux-2.6-2117_sata-via-suspend.patch
Patch2228: linux-2.6-2118_scsi-constants.patch

# Wireless bits
Patch2300: linux-2.6-wireless.patch
Patch2301: git-wireless-dev.patch
Patch2302: git-iwlwifi.patch
Patch2303: linux-2.6-bcm43xx-pci-neuter.patch
Patch2304: madwifi-Makefile.inc-r2323-20070512.patch

# Assorted dyntick/clock/timer fixes.
Patch2402: linux-2.6-acpi-keep-tsc-stable-when-lapic-timer-c2-ok-is-set.patch
Patch2403: linux-2.6-clockevents-fix-resume-logic.patch

# ACPI bits
Patch2500: linux-2.6-acpi-unblacklist-dell-gx240.patch
Patch2501: linux-2.6-acpi-dock-oops.patch

# Excessive wakeups.
Patch2600: linux-2.6-wakeups-hdaps.patch

# Add the new firewire stack. Diff between the v2.6.20 tag and commit
# a0ab4547b23c09541bc47a294a1397b3b0415bfe in the linux1394 git tree.
Patch5000: linux-2.6-firewire.patch
Patch5001: linux-2.6-firewire-be32-fix.patch

#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here.
# Not patches you're too lazy for to put in the proper place.
#

Patch10000: linux-2.6-compile-fixes.patch
Patch10001: linux-2.6-warnings-inline.patch
Patch10002: linux-2.6-warnings-emptymacros.patch
Patch10003: linux-2.6-warnings-register.patch

# Xen hypervisor patches (20000+)
Patch20000: xen-printf-rate-limit.patch
Patch20001: xen-11668-hvm_disable_fix.patch
Patch20002: xen-dom0-reboot.patch

# 
# 30000 - 39999 is for Momonga misc patch
#
Patch30000: linux-2.6-logo_momonga.patch
%if %{with_swsusp2}
#SWSUSP2
# Web: http://swsusp.sf.net/
#      http://softwaresuspend.berlios.de/wiki/KnownIssues
# ML : http://lists.berlios.de/pipermail/softwaresuspend-devel/2004-December/
# URL: http://www.suspend2.net/downloads/all/
#      (ex:  software-suspend-2.1.9.9-for-2.6.12.tar.bz2)
#                          (swsusp2ver) (swsusp2kver)
%global swsusp2ver 2.2.9.16
%global swsusp2kver 2.6.21
%global swsusp2name suspend2-%{swsusp2ver}-for-%{swsusp2kver}
Patch30100: http://www.suspend2.net/downloads/all/%{swsusp2name}.patch.bz2
NoPatch: 30100
# SWSUSP2
Patch30101: linux-2.6.9-swsusp-smp2.patch
%endif

%if %{usagi_ipv6}
## ipv6 subsystem update
# %global md5patch30200 4a89f94e5d676249287bf57e55fe4ed6
# Patch30200: %{usagiuri}/%{usagisnapver_month}/%{usagipatchname}
# NoPatch: 30200
Patch30200: %{usagipatchname}
%endif

%if %{with_kdb}
# kdb
Patch30300: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-common-2.bz2
Patch30301: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-i386-2.bz2
Patch30302: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-ia64-1.bz2
Patch30303: ftp://oss.sgi.com/www/projects/kdb/download/%{kdb_ver}/kdb-%{kdb_ver}-%{kdb_kernel_ver}-x86_64-2.bz2
%endif

# Patch30400: For compilation of NVIDIA driver (ver 1.0-6111)
##   http://www.uwsg.indiana.edu/hypermail/linux/kernel/0410.2/0753.html
%NoPatch 30400 http://ck.kolivas.org/patches/2.6/2.6.9/2.6.9-ck1/patches/nvidia_compat.diff e391697899c02b63bcf8cc550fc6a539

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{kversion}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
#global _use_internal_dependency_generator 0
#define __find_provides %_sourcedir/find-provides %{_tmppath}
#define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%ifarch x86_64
Obsoletes: kernel-smp
%endif

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package debuginfo
Summary: Debug information for package %{name}
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debuginfo-%{_target_cpu} = %{KVERREL}
%description debuginfo
This package provides debug information for package %{name}
This is required to use SystemTap with %{name}-%{KVERREL}.

%package debuginfo-common
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
%description debuginfo-common
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}
Prereq: findutils
%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}smp
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%package smp-debuginfo
Summary: Debug information for package %{name}-smp
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-%smp-debuginfo-%{_target_cpu} = %{KVERREL}
%description smp-debuginfo
This package provides debug information for package %{name}-smp
This is required to use SystemTap with %{name}-smp-%{KVERREL}.

%package smp-devel
Summary: Development package for building kernel modules to match the SMP kernel.
Group: System Environment/Kernel
Provides: kernel-smp-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}smp
Provides: kernel-devel = %{version}-%{release}smp
AutoReqProv: no
Prereq: findutils
%description smp-devel
This package provides kernel headers and makefiles sufficient to build modules
against the SMP kernel package.


%package PAE
Summary: The Linux kernel compiled for PAE capable machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}PAE
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Obsoletes: kernel-smp < 2.6.18
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

%package PAE-debuginfo
Summary: Debug information for package %{name}-PAE
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-%PAE-debuginfo-%{_target_cpu} = %{KVERREL}
%description PAE-debuginfo
This package provides debug information for package %{name}-PAE
This is required to use SystemTap with %{name}-PAE-%{KVERREL}.

%package PAE-devel
Summary: Development package for building kernel modules to match the PAE kernel.
Group: System Environment/Kernel
Provides: kernel-PAE-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}PAE
Provides: kernel-devel = %{version}-%{release}PAE
AutoReqProv: no
Prereq: findutils
%description PAE-devel
This package provides kernel headers and makefiles sufficient to build modules
against the PAE kernel package.

%if %{debugbuildsenabled}
%package PAE-debug
Summary: The Linux kernel compiled with extra debugging enabled for PAE capable machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}PAE-debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description PAE-debug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package PAE-debug-debuginfo
Summary: Debug information for package %{name}-PAE-debug
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debug-debuginfo-%{_target_cpu} = %{KVERREL}
%description PAE-debug-debuginfo
This package provides debug information for package %{name}-PAE-debug

%package PAE-debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Prereq: findutils
Provides: kernel-PAE-debug-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}PAE-debug
Provides: kernel-devel = %{version}-%{release}PAE-debug
%description PAE-debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.
%endif


%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.


%if %{?debugbuildsenabled}
%package debug
Summary: The Linux kernel compiled with extra debugging enabled.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package debug-debuginfo
Summary: Debug information for package %{name}-debug
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debug-debuginfo-%{_target_cpu} = %{KVERREL}
%description debug-debuginfo
This package provides debug information for package %{name}-debug

%package debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Prereq: findutils
Provides: kernel-debug-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}debug
Provides: kernel-devel = %{version}-%{release}debug
%description debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.
%endif


%package xen
Summary: The Linux kernel compiled for Xen VM operations
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{version}-%{release}xen
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{xen_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description xen
This package includes a version of the Linux kernel which
runs in Xen VM. It works for both priviledged and unpriviledged guests.

%package xen-debuginfo
Summary: Debug information for package %{name}-xen
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-xen-debuginfo-%{_target_cpu} = %{KVERREL}
%description xen-debuginfo
This package provides debug information for package %{name}-xen
This is required to use SystemTap with %{name}-xen-%{KVERREL}.

%package xen-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xen-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}xen
Provides: kernel-devel = %{version}-%{release}xen
Prereq: findutils
%description xen-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package kdump
Summary: A minimal Linux kernel compiled for kernel crash dumps.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-drm-nouveau = 6
Provides: kernel-%{_target_cpu} = %{version}-%{release}kdump
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.

%package kdump-debuginfo
Summary: Debug information for package %{name}-kdump
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-kdump-debuginfo-%{_target_cpu} = %{KVERREL}
%description kdump-debuginfo
This package provides debug information for package %{name}-kdump
This is required to use SystemTap with %{name}-kdump-%{KVERREL}.

%package kdump-devel
Summary: Development package for building kernel modules to match the kdump kernel.
Group: System Environment/Kernel
Provides: kernel-kdump-devel-%{_target_cpu} = %{version}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}kdump
Provides: kernel-devel = %{version}-%{release}kdump
AutoReqProv: no
Prereq: findutils
%description kdump-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kdump kernel package.


%prep
print_specopt() {
## echo the specopt values
cat <<EOF
Configurations:
  usagi_ipv6 ............ %{usagi_ipv6}
  header arch ........... %{hdrarch}

Generic kernel packages:
  up .................... %{with_up}
  headers ............... %{with_headers}
  smp ................... %{with_smp}
  xen ................... %{with_xen}

Extras:
  kdb ................... %{with_kdb}
  madwifi ............... %{with_madwifi}
  nilfs ................. %{with_nilfs}
  btrfs ................. %{with_btrfs}
  unionfs ............... %{with_unionfs} 
EOF
}

print_specopt | tee kernel-specopt.log

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.
if [ ! -d kernel-%{kversion}/vanilla ]; then
  # Ok, first time we do a make prep.
  rm -f pax_global_header
%setup -q -n %{name}-%{version} -c
  mv linux-%{kversion} vanilla
else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
  if [ -d linux-%{kversion}.%{_target_cpu} ]; then
     # Just in case we ctrl-c'd a prep already
     rm -rf deleteme.%{_target_cpu}
     # Move away the stale away, and delete in background.
     mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
     rm -rf deleteme.%{_target_cpu} &
  fi
fi

cp -rl vanilla linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

pushd .

# Momonga logo
cp %{SOURCE100} drivers/video/logo
cp %{SOURCE101} drivers/video/logo
cp %{SOURCE102} drivers/video/logo
cp %{SOURCE103} drivers/video/logo
cp %{SOURCE104} drivers/video/logo/logo_spu_clut224.ppm

cd ..
%if %{with_madwifi}
tar zxf %{SOURCE2400}
%endif

%if %{with_ipw3945}
tar zxf %{SOURCE2450}
%endif

%if %{with_nilfs}
tar jxf %{SOURCE2600}
%endif

%if %{with_btrfs}
tar jxf %{SOURCE2650}
%endif

# ivtv
%if %{with_ivtv}
tar zxf %{SOURCE2700}
%endif

popd

%if %{build_rc}
# Apply latest prepatch
%patch0 -p1
%endif

%if %{build_ext}
# Update to latest upstream.
%patch1 -p1
%endif

%if %{build_git}
# Apply snapshot git patch
%patch2 -p1
%endif

%patch3 -p1 -R

%patch7 -p1 -b .cfs_sched

# Patches 10 through 100 are meant for core subsystem upgrades

# Roland's utrace ptrace replacement.
%patch10 -p1
%patch11 -p1

# Power management fixes
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1

# sysrq works always
%patch16 -p1

# DRM support for 965GM
%patch17 -p1

# backport DRM
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1

# backport AGPGART
%patch29 -p1

# Architecture patches

%ifarch %{ix86} x86_64
# SWSUSP2
#%patch48 -p1
%endif 

# ipv6 subsystem update
%if %{usagi_ipv6}
%patch50 -p1
%endif

# TC9020
mkdir TC902X
pushd TC902X
%{__unzip} %{SOURCE500}
%{__cp} README.TXT ../Documentation/networking/tc902x.txt
%{__tar} zxf tc902x.v203.tar.gz
mkdir ../drivers/net/tc902x
%{__cp} *.h *.c ../drivers/net/tc902x/
%{__mv} ../drivers/net/tc902x/tc902x.c ../drivers/net/tc902x/tc902x_core.c
chmod 644 ../drivers/net/tc902x/*
popd

#
# x86(-64)
#
# Compile 686 kernels tuned for Pentium4.
%patch200 -p1
# add vidfail capability;
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch201 -p1
# EDAC support for K8
%patch202 -p1
# Suppress APIC errors on UP x86-64.
%patch203 -p1
# Don't delete cpu_devs data to identify different x86 types in late_initcall
%patch204 -p1
# quirk for Siemens Nixdorf AG FSC Multiprocessor Interrupt Controller
%patch206 -p1
# Blacklist Dell Optiplex 320 from using the HPET
%patch207 -p1
# Add x86-64 PM_TRACE support.
%patch209 -p1

#
# PowerPC
#
# Alleviate G5 thermal shutdown problems
%patch300 -p1
# Ensure slab objects are aligned enough for a uint64_t (#235392)
%patch301 -p1
#%patch302 -p1
# Temporary hack to work around GCC PR #25724 / #21237
%patch303 -p1
# Fix up ibmvscsi for combined pSeries/iSeries build
%patch304 -p1
# Move pmac_zilog to its newly-registered device number
%patch305 -p1
# Ensure initrd memory is reserved at boot
%patch306 -p1
%patch307 -p1
%patch308 -p1
%patch309 -p1

# uevent support for of_platform device
%patch310 -p1
%patch311 -p1
%patch312 -p1
%patch313 -p1

%patch330 -p1
%patch331 -p1
%patch332 -p1
%patch333 -p1
# Efika Ethernet
%patch340 -p1
%patch341 -p1

# PlayStation 3 support
%patch350 -p1
%patch351 -p1
%patch352 -p1
%patch353 -p1
%patch354 -p1
%patch355 -p1
%patch356 -p1
%patch357 -p1
%patch358 -p1
%patch359 -p1
%patch360 -p1
%patch361 -p1
%patch362 -p1

%patch370 -p1
%patch371 -p1
%patch372 -p1
%patch373 -p1
%patch374 -p1
%patch375 -p1
%patch376 -p1
%patch377 -p1

# Fix me PS3 SPU logo
# %patch399 -p1

# S390

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch800 -p1

# Exec shield
%patch810 -p1

#
# GPG signed kernel modules
#
%patch900 -p1
%patch901 -p1
%patch902 -p1
%patch903 -p1
%patch904 -p1
%patch905 -p1
%patch906 -p1

# Tux
#%patch910 -p1

#
# Xen
#
%if %{includexen}
#
# Apply the main xen patch...
#%patch951 -p1
%patch950 -p1 -b .p.xen
#
# ... and back out all the tpm additions, they need fixing
#
for f in `find drivers/char/tpm -type f -name "*.p.xen"` ; do \
    g=`dirname $f`/`basename $f .p.xen`; \
    mv "$f" "$g"; \
    if [ ! -s "$g" ] ; then rm -f "$g" ; fi; \
done
# Delete the rest of the backup files, they just confuse the build later
find -name "*.p.xen" | xargs rm -f

# Xen utrace
%patch951 -p1
%patch952 -p1
%patch953 -p1
# Xen exec-shield bits
%patch954 -p1
%patch955 -p1
%patch956 -p1
# ia64 xen cleanups for kexec/kdump
%patch958 -p1

# xen blktap fixes
%patch960 -p1
# The blktap patch needs to rename a file.  For now, that is far more easily
# done in the spec file than in the patch itself.
mv drivers/xen/blktap/blktap.c drivers/xen/blktap/blktapmain.c
%patch961 -p1
%patch962 -p1
%patch963 -p1

# xen framebuffer patches
%patch990 -p1

%endif

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#


# Various low-impact patches to aid debugging.
%patch1010 -p1
%patch1011 -p1
%patch1012 -p1
%patch1013 -p1
%patch1015 -p1
# Only spew extra warnings on rawhide builds.
%if ! %{debugbuildsenabled}
%patch1016 -p1
%endif
%patch1018 -p1
%patch1019 -p1
%patch1020 -p1
%patch1021 -p1
%patch1022 -p1
%if %{includexen}
%patch1023 -p1
%endif

#
# Make /dev/mem a need-to-know function
#
%patch1050 -p1
%if %{includexen}
%patch1051 -p1
%endif

#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1
%if %{includexen}
%patch1061 -p1
%endif

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

#
# SCSI Bits.
#
# Fix old SCSI adapter crashes with CD-ROM
%patch1100 -p1
# fix cpqarray pci enable
%patch1101 -p1

#
# Various NFS/NFSD fixes.
#
# Fix badness.
%patch1201 -p1

# NIC driver fixes
# Don't print warnings about MSI failures on e1000
%patch1300 -p1

# Filesystem patches.
# Squashfs
%patch1400 -p1
# GFS2 update
%patch1410 -p1
# Reiser4
%patch1420 -p1
# ReiserFS
%patch1430 -p1
# unionfs
%if %{with_unionfs}
%patch1440 -p1
%endif
# XFS
%patch1450 -p1

# Networking
# Disable easy to trigger printk's.
%patch1500 -p1

# Misc fixes
# Add missing MODULE_VERSION tags to some modules.
%patch1600 -p1
# Fix SHA1 alignment problem on ia64
%patch1601 -p1
# The input layer spews crap no-one cares about.
%patch1610 -p1
# don't wakeup ondemand timer whilst idle.
%patch1620 -p1
# Update KVM.
%patch1630 -p1
# KVM: Detect if AMD svm was disabled by BIOS
%patch1631 -p1
# KVM: Fix above patch on 32-bit
%patch1632 -p1
# KVM: reinit real-mode TSS before switching back
%patch1633 -p1
# Allow overriding module parameters from kernel command_line
#%patch1640 -p1
# Allow to use 480600 baud on 16C950 UARTs
%patch1650 -p1
# Allow large files on UDF
%patch1660 -p1
%patch1661 -p1
%patch1662 -p1
# fix oops in sysfs_readdir
%patch1670 -p1
# Fix XFS umount bug.
%patch1681 -p1
# Align kernel data segment to page boundary.
%patch1690 -p1
# DVB spinlock bug
%patch1700 -p1
# NFS: Added support to turn off the NFSv3 READDIRPLUS RPC.
%patch1710 -p1
# Missing braces
%patch1711 -p1
# setuid /proc/self/maps fix.
%patch1720 -p1
# Fix ACPI suspend / device suspend ordering problem
%patch1730 -p1
# Add a safety net to softlockup so that it doesn't prevent installs.
%patch1740 -p1
# Speed up spinlock debug.
%patch1770 -p1
# Silence some useless messages that still get printed with 'quiet'
%patch1771 -p1
# softirqs: print out irq-trace events
%patch1781 -p1

# OLPC specific patches
%if 0%{?olpc}
# Marvell Libertas wireless driver
%patch1791 -p1
# OLPC touchpad
%patch1792 -p1
%endif

# temporarily restore START_ARRAY ioctl
%patch1793 -p1
# Fix i82875 EDAC driver setup so X will start
%patch1794 -p1
# Work around sysfs/uevent use-after-free problems with Bluetooth HID
%patch1795 -p1

# Fix the SELinux mprotect checks on executable mappings
%patch1801 -p1

# Warn about obsolete functionality usage.
%patch1900 -p1
# Remove kernel-internal functionality that nothing external should use.
%patch1910 -p1

#
# VM related fixes.
#
# Re-add cond_resched to invalidate_mapping_pages()
%patch2000 -p1
# Silence GFP_ATOMIC failures.
%patch2001 -p1

# Changes to upstream defaults.
# Use UTF-8 by default on VFAT.
%patch2100 -p1
# Use unicode VT's by default.
%patch2103 -p1
# Disable NMI watchdog by default.
%patch2105 -p1
# Disable MMCONFIG & MSI by default.
%patch2106 -p1

# Enable PATA ports on Promise SATA.
#%patch2200 -p1
# HPA support for libata.
%patch2201 -p1
# sata_nv: Don't attempt using ADMA for (READ|SET)_MAX commands
%patch2202 -p1
# Disable ATAPI DMA on ALI chipsets.
%patch2203 -p1
# libata: don't initialize sg in ata_exec_internal() if DMA_NONE
# ia64 ata quirk
%patch2204 -p1
# remove the wildcard from sata_nv driver
%patch2206 -p1
# pata_pcmcia.c: add card ident for jvc cdrom
%patch2207 -p1
# Add libata ID's for ATI SB700
%patch2208 -p1
# hpt3x2n: Correct revision boundary
%patch2209 -p1
# pata_sis: Fix and clean up some timing setups
%patch2210 -p1
# libata: always use polling SETXFER
%patch2211 -p1
# pata_ali: limit DMA speeds
%patch2212 -p1
# libata: use PIO when xfer is not a multiple of 16
%patch2213 -p1
# libata: call check_dma with qc better prepared
%patch2214 -p1
# libata: add intel ich8m (santa rosa) pata ID
%patch2215 -p1

# Add critical wireless updates from 2.6.22
%patch2300 -p1
# Add the new wireless stack and drivers from wireless-dev
%patch2301 -p1
# Update iwlwifi driver from www.intellinuxwireless.org git tree
%patch2302 -p1
# avoid bcm43xx vs bcm43xx-mac80211 PCI ID conflicts
%patch2303 -p1
# madwifi
%if %{with_madwifi}
pushd ../madwifi*
%patch2304 -p1
popd
%endif

# Assorted dyntick/clock/timer fixes.
%patch2402 -p1
%patch2403 -p1

# ACPI patches
# Remove Dell Optiplex GX240 from the ACPI blacklist
%patch2500 -p1
# Fix ACPI dock oops (#238054)
%patch2501 -p1

# Fix excessive wakeups
# Make hdaps timer only tick when in use.
%patch2600 -p1

#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#

# Pull in the new firewire stack
%patch5000 -p1
%patch5001 -p1

#
# final stuff
#

#
# misc small stuff to make things compile or otherwise improve performance
#
#%patch10000 -p1
#%patch10001 -p1
%patch10002 -p1
%patch10003 -p1

# Momonga logo
%patch30000 -p1

%if %{with_swsusp2}
%patch30100 -p1
%patch30101 -p1
%endif

%if %{with_usagi_ipv6}
%patch30200 -p1
%endif

%if %{with_kdb}
%patch30300 -p1
%patch30301 -p1
%patch30302 -p1
%patch30303 -p1
%endif

%if %{with_nvidia}
%patch30400 -p1
%endif

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -f %{all_arch_configs} .


%if 0%{?rhel}
# don't need these for relocatable kernels
rm -f kernel-%{kversion}-{i686,x86_64}-kdump.config
%endif

%if 0%{?olpc}
# don't need these for OLPC
rm -f kernel-%{kversion}-*PAE*.config
rm -f kernel-%{kversion}-*xen*.config
rm -f kernel-%{kversion}-*kdump*.config
%endif

%if 0%{?debugbuildsenabled}
%else
rm -f kernel-%{kversion}-*-debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch nonint_oldconfig > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

cd ..

# Unpack the Xen tarball.
%if %{includexen}
cp %{SOURCE2} .
if [ -d xen ]; then
  rm -rf xen
fi
%setup -D -T -q -n %{name}-%{version} -a1
cd xen
# Any necessary hypervisor patches go here
%patch20000 -p1
%patch20001 -p2
%patch20002 -p2
%endif


###
### build
###
%build

%if %{usesparse}
%define sparse_mflags	C=1
%endif

#
# Create gpg keys for signing the modules
#
%if %{with_modsign}
gpg --homedir . --batch --gen-key %{SOURCE11}
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
make linux-%{kversion}.%{_target_cpu}/scripts/bin2c
linux-%{kversion}.%{_target_cpu}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}.%{_target_cpu}/crypto/signature/key.h
%endif

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3

    # Pick the right config file for the kernel we're building
    if [ -n "$Flavour" ] ; then
      Config=kernel-%{kversion}-%{_target_cpu}-$Flavour.config
      DevelDir=/usr/src/kernels/%{KVERREL}-$Flavour-%{_target_cpu}
      DevelLink=/usr/src/kernels/%{KVERREL}$Flavour-%{_target_cpu}
    else
      Config=kernel-%{kversion}-%{_target_cpu}.config
      DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
      DevelLink=
    fi

    KernelVer=%{version}-%{release}$Flavour
    echo BUILDING A KERNEL FOR $Flavour %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$Flavour/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    if [ "$KernelImage" == "x86" ]; then
       KernelImage=arch/$Arch/boot/bzImage
    fi

    make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initrd-$KernelVer.img
    cp $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi

    if [ "$Flavour" == "kdump" ]; then
        cp vmlinux $RPM_BUILD_ROOT/%{image_install_path}/vmlinux-$KernelVer
        rm -f $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

    # Create the kABI metadata for use in packaging
#   echo "**** GENERATING kernel ABI metadata ****"
#   gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
#   chmod 0755 %_sourcedir/kabitool
#   if [ ! -e $RPM_SOURCE_DIR/kabi_whitelist ]; then
#       %_sourcedir/kabitool -b $RPM_BUILD_ROOT/$DevelDir -k $KernelVer -l $RPM_BUILD_ROOT/kabi_whitelist
#   else
#       cp $RPM_SOURCE_DIR/kabi_whitelist $RPM_BUILD_ROOT/kabi_whitelist
#   fi
#   rm -f %{_tmppath}/kernel-$KernelVer-kabideps
#    %_sourcedir/kabitool -b . -d %{_tmppath}/kernel-$KernelVer-kabideps -k $KernelVer -w $RPM_BUILD_ROOT/kabi_whitelist

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
#    mv $RPM_BUILD_ROOT/kabi_whitelist $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
#    cp symsets-$KernelVer.tar.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ "$Arch" = "x86_64" ]; then
      cp -a asm-i386 $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    fi
    # While arch/powerpc/include/asm is still a symlink to the old
    # include/asm-ppc{64,} directory, include that in kernel-devel too.
    if [ "$Arch" = "powerpc" -a -r ../arch/powerpc/include/asm ]; then
      cp -a `readlink ../arch/powerpc/include/asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      ln -sf ../../../include/asm-ppc* asm
      popd
    fi
%if %{includexen}
    cp -a xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%endif

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # gpg sign the modules
%if %{with_modsign}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
    KEYFLAGS="--no-default-keyring --homedir .."
    KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec"
    KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub"
    export KEYFLAGS

    for i in `cat modnames`
    do
      sh ./scripts/modsign/modsign.sh $i Red
      mv -f $i.signed $i
    done
    unset KEYFLAGS
%endif
    # mark modules executable so that strip-to-file can strip them
    cat modnames | xargs chmod u+x

    # Generate a list of modules for SCSI, sata/pata, and networking.
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.scsi
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.libata
    touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.networking
    for i in `cat modnames | grep drivers | grep -v drivers\/ata`
    do
      if [ $(nm $i |grep --count scsi_add_host) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.scsi
      fi
    done

    for i in `cat modnames | grep drivers\/ata`
    do
      if [ $(nm $i |grep --count ata_device_add) -ne 0 -o $(nm $i |grep --count ata_pci_init_one) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.libata
      fi
    done

    for i in `cat modnames |grep drivers`
    do
      if [ $(nm $i |grep --count register_netdev) -ne 0 ];
      then
        basename `echo $i` >> $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.networking
      fi
    done

    # detect missing or incorrect license tags
    for i in `cat modnames`
    do
      echo -n "$i "
      /sbin/modinfo -l $i >> modinfo
    done
    cat modinfo |\
      grep -v "^GPL" |
      grep -v "^Dual BSD/GPL" |\
      grep -v "^Dual MPL/GPL" |\
      grep -v "^GPL and additional rights" |\
      grep -v "^GPL v2" && exit 1
    rm -f modinfo
    rm -f modnames
    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias ccwmap dep ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    [ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink

%ifarch %{ix86} x86_64 ppc
    # madwifi
%if %{with_madwifi}
    if [ "$Flavour" != "xenU" ]; then
      cd ../madwifi*
%ifarch ppc
      export TARGET=powerpc-be-eabi
      export KERNELRELEASE=%{version}-%{rel}
      export TOOLPREFIX='/usr/bin/'
%endif
      make modules KERNELPATH=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
      make install-modules DESTDIR=%{buildroot} KERNELPATH=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} KERNELCONF=%{buildroot}/lib/modules/$KernelVer/build/.config KERNELRELEASE=$KernelVer
      cd -
    fi
%endif
%endif

%if %{with_ipw3945}    
%ifarch %{ix86} x86_64
    # ipw3945
    if [ "$Flavour" != "xenU" ]; then
      cd ../ipw3945-%{ipw3945_kmod_ver}/
      make clean
      perl -pi -e's,/sbin/depmod,:,g' Makefile
      make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} IEEE80211_INC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}/include/
      make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} IEEE80211_INC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}/include/ KMISC=%{buildroot}/lib/modules/$KernelVer/kernel/drivers/net/wireless/ install
      cd -
    fi
%endif
%endif

%ifarch %{ix86} x86_64
%if %{with_nilfs}
    # nilfs
    cd ../nilfs-%{nilfs_ver}/fs
    perl -pi -e "s,/sbin/depmod,:,g" Makefile
    make clean
    make KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} MDIR=%{buildroot}/lib/modules/$KernelVer/kernel/fs/nilfs/ KVER="%{kversion}-%{release}"
    make install KSRC=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} MDIR=%{buildroot}/lib/modules/$KernelVer/kernel/fs/nilfs/ KVER="%{kversion}-%{release}"
    cd -
%endif
%endif

%ifarch %{ix86} x86_64
%if %{with_btrfs}
    # btrfs
    cd ../btrfs-%{btrfs_ver}
    make KERNELDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu} 
    mkdir -p %{buildroot}/lib/modules/$KernelVer/kernel/fs/btrfs
    install -m 644 -c btrfs.ko %{buildroot}/lib/modules/$KernelVer/kernel/fs/btrfs/
    cd -
%endif
%endif

%ifarch %{ix86} x86_64
    # ivtv
    %if %{with_ivtv}
    if [ "$Flavour" != "xenU" ]; then
      cd ../ivtv-%{ivtv_ver}
        make -C driver KDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
        make modules_install INSTALL_MOD_PATH=%{buildroot} INSTALL_MOD_DIR=kernel/drivers/media/video/ivtv -C %{buildroot}/lib/modules/$KernelVer/build M=%{_builddir}/kernel-%{kversion}/ivtv-%{ivtv_ver}/driver
        make -C i2c-drivers KDIR=%{_builddir}/kernel-%{kversion}/linux-%{kversion}.%{_target_cpu}
        make modules_install INSTALL_MOD_PATH=%{buildroot} INSTALL_MOD_DIR=kernel/drivers/media/video -C %{buildroot}/lib/modules/$KernelVer/build M=%{_builddir}/kernel-%{kversion}/ivtv-%{ivtv_ver}/i2c-drivers
      cd -
    fi
    %endif
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{includexen}
%if %{with_xen}
  cd xen
  mkdir -p $RPM_BUILD_ROOT/%{image_install_path} $RPM_BUILD_ROOT/boot
  make %{?_smp_mflags} %{xen_flags}
  install -m 644 xen.gz $RPM_BUILD_ROOT/%{image_install_path}/xen.gz-%{KVERREL}
  install -m 755 xen-syms $RPM_BUILD_ROOT/boot/xen-syms-%{KVERREL}
  cd ..
%endif
%endif

cd linux-%{kversion}.%{_target_cpu}

%if %{debugbuildsenabled}
%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%endif
%if %{with_pae}
BuildKernel %make_target %kernel_image PAE-debug
%endif
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_smp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{includexen}
%if %{with_xen}
BuildKernel %xen_target %xen_image xen
%endif
%endif

%if %{with_kdump}
BuildKernel %make_target %kernel_image kdump
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%files debuginfo-common
%defattr(-,root,root)
/usr/src/debug/%{name}-%{version}/linux-%{kversion}.%{_target_cpu}
%if %{includexen}
%if %{with_xen}
/usr/src/debug/%{name}-%{version}/xen
%endif
%endif
%dir /usr/src/debug
%dir /usr/lib/debug
%dir /usr/lib/debug/%{image_install_path}
%dir /usr/lib/debug/lib
%dir /usr/lib/debug/lib/modules
%dir /usr/lib/debug/usr/src/kernels
%endif
%endif

###
### install
###

%install

cd linux-%{kversion}.%{_target_cpu}

%if %{includexen}
%if %{with_xen}
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
rm -f $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf <<\EOF
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg
EOF
chmod 444 $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
%endif
%endif

%if %{with_doc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE /dev/null >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%post
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ]; then
  if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel/' /etc/sysconfig/kernel || exit $?
  fi
fi
/sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KVERREL} || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL} || exit $?
#fi

%post devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post smp
/sbin/new-kernel-pkg --package kernel-smp --mkinitrd --depmod --install %{KVERREL}smp || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}smp || exit $?
#fi

%post smp-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post PAE
if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel-PAE/' /etc/sysconfig/kernel
fi
/sbin/new-kernel-pkg --package kernel-PAE --mkinitrd --depmod --install %{KVERREL}PAE || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}PAE || exit $?
#fi

%post PAE-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi


%if %{debugbuildsenabled}
%post debug
/sbin/new-kernel-pkg --package kernel-debug --mkinitrd --depmod --install %{KVERREL}debug || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}debug || exit $?
#fi

%post debug-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-debug-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post PAE-debug
if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel-PAE/' /etc/sysconfig/kernel
fi
/sbin/new-kernel-pkg --package kernel-PAE --mkinitrd --depmod --install %{KVERREL}PAE-debug || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}PAE || exit $?
#fi

%post PAE-debug-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi
%endif

%post xen
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ]; then
  if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-xen[0U]/DEFAULTKERNEL=kernel-xen/' /etc/sysconfig/kernel || exit $?
  fi
fi
if [ -e /proc/xen/xsd_kva -o ! -d /proc/xen ]; then
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install --multiboot=/%{image_install_path}/xen.gz-%{KVERREL} %{KVERREL}xen || exit $?
else
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install %{KVERREL}xen || exit $?
fi
if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}xen || exit $?
#fi

%post xen-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post kdump
/sbin/new-kernel-pkg --package kernel-kdump --mkinitrd --depmod --install %{KVERREL}kdump || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --add-kernel %{KVERREL}kdump || exit $?
#fi

%post kdump-devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi


%preun
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL} || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL} || exit $?
#fi

%preun smp
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL}smp || exit $?
#fi

%preun PAE
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}PAE || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL}PAE || exit $?
#fi

%preun kdump
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}kdump || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL}kdump || exit $?
#fi

%if %{debugbuildsenabled}
%preun debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug || exit $?
if [ -x /sbin/weak-modules ]
then
    /sbin/weak-modules --remove-kernel %{KVERREL}debug || exit $?
fi

%preun PAE-debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}PAE-debug || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL}PAE || exit $?
#fi
%endif

%preun xen
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xen || exit $?
#if [ -x /sbin/weak-modules ]
#then
#    /sbin/weak-modules --remove-kernel %{KVERREL}xen || exit $?
#fi

###
### file lists
###

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

%if %{with_up}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}
/usr/lib/debug/usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif
%endif

%files
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
#/boot/symvers-%{KVERREL}.gz
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
/lib/modules/%{KVERREL}/extra
/lib/modules/%{KVERREL}/updates
/lib/modules/%{KVERREL}/weak-updates
/lib/modules/%{KVERREL}/modules.scsi
/lib/modules/%{KVERREL}/modules.libata
/lib/modules/%{KVERREL}/modules.networking
%ghost /boot/initrd-%{KVERREL}.img

%files devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif


%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif


%if %{debugbuildsenabled}
%if %{with_debug}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files debug-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}debug.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}debug
/usr/lib/debug/usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
%endif
%endif

%files debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
#/boot/symvers-%{KVERREL}debug.gz
/boot/config-%{KVERREL}debug
%dir /lib/modules/%{KVERREL}debug
/lib/modules/%{KVERREL}debug/kernel
/lib/modules/%{KVERREL}debug/build
/lib/modules/%{KVERREL}debug/source
/lib/modules/%{KVERREL}debug/extra
/lib/modules/%{KVERREL}debug/updates
/lib/modules/%{KVERREL}debug/weak-updates
/lib/modules/%{KVERREL}debug/modules.scsi
/lib/modules/%{KVERREL}debug/modules.libata
/lib/modules/%{KVERREL}debug/modules.networking
%ghost /boot/initrd-%{KVERREL}debug.img

%files debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}debug-%{_target_cpu}
%endif
%endif



%if %{with_pae}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files PAE-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}PAE.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}PAE
/usr/lib/debug/usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu}
%endif
%endif

%files PAE
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}PAE
/boot/System.map-%{KVERREL}PAE
#/boot/symvers-%{KVERREL}PAE.gz
/boot/config-%{KVERREL}PAE
%dir /lib/modules/%{KVERREL}PAE
/lib/modules/%{KVERREL}PAE/kernel
/lib/modules/%{KVERREL}PAE/build
/lib/modules/%{KVERREL}PAE/source
/lib/modules/%{KVERREL}PAE/extra
/lib/modules/%{KVERREL}PAE/updates
/lib/modules/%{KVERREL}PAE/weak-updates
/lib/modules/%{KVERREL}PAE/modules.scsi
/lib/modules/%{KVERREL}PAE/modules.libata
/lib/modules/%{KVERREL}PAE/modules.networking
%ghost /boot/initrd-%{KVERREL}PAE.img

%files PAE-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-PAE-%{_target_cpu}
/usr/src/kernels/%{KVERREL}PAE-%{_target_cpu}

%if %{debugbuildsenabled}
%if %{with_debug}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files PAE-debug-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}PAE-debug.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}PAE-debug
/usr/lib/debug/usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu}
%endif
%endif

%files PAE-debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}PAE-debug
/boot/System.map-%{KVERREL}PAE-debug
#/boot/symvers-%{KVERREL}PAE-debug.gz
/boot/config-%{KVERREL}PAE-debug
%dir /lib/modules/%{KVERREL}PAE-debug
/lib/modules/%{KVERREL}PAE-debug/kernel
/lib/modules/%{KVERREL}PAE-debug/build
/lib/modules/%{KVERREL}PAE-debug/source
/lib/modules/%{KVERREL}PAE-debug/extra
/lib/modules/%{KVERREL}PAE-debug/updates
/lib/modules/%{KVERREL}PAE-debug/weak-updates
/lib/modules/%{KVERREL}PAE-debug/modules.scsi
/lib/modules/%{KVERREL}PAE-debug/modules.libata
/lib/modules/%{KVERREL}PAE-debug/modules.networking
%ghost /boot/initrd-%{KVERREL}PAE-debug.img

%files PAE-debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-PAE-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}PAE-debug-%{_target_cpu}
%endif
%endif
# PAE
%endif


%if %{with_smp}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files smp-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}smp.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}smp
/usr/lib/debug/usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
%endif
%endif

%files smp
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
#/boot/symvers-%{KVERREL}smp.gz
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
/lib/modules/%{KVERREL}smp/extra
/lib/modules/%{KVERREL}smp/updates
/lib/modules/%{KVERREL}smp/weak-updates
/lib/modules/%{KVERREL}smp/modules.scsi
/lib/modules/%{KVERREL}smp/modules.libata
/lib/modules/%{KVERREL}smp/modules.networking
%ghost /boot/initrd-%{KVERREL}smp.img

%files smp-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
/usr/src/kernels/%{KVERREL}smp-%{_target_cpu}
%endif


%if %{includexen}
%if %{with_xen}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files xen-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}xen.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}xen
/usr/lib/debug/usr/src/kernels/%{KVERREL}-xen-%{_target_cpu}
/usr/lib/debug/boot/xen*-%{KVERREL}.debug
%endif
%endif

%files xen
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xen
/boot/System.map-%{KVERREL}xen
#/boot/symvers-%{KVERREL}xen.gz
/boot/config-%{KVERREL}xen
/%{image_install_path}/xen.gz-%{KVERREL}
/boot/xen-syms-%{KVERREL}
%dir /lib/modules/%{KVERREL}xen
/lib/modules/%{KVERREL}xen/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xen/build
/lib/modules/%{KVERREL}xen/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
/lib/modules/%{KVERREL}xen/extra
/lib/modules/%{KVERREL}xen/updates
/lib/modules/%{KVERREL}xen/weak-updates
/lib/modules/%{KVERREL}xen/modules.scsi
/lib/modules/%{KVERREL}xen/modules.libata
/lib/modules/%{KVERREL}xen/modules.networking
%ghost /boot/initrd-%{KVERREL}xen.img

%files xen-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xen-%{_target_cpu}
%endif
%endif

%if %{with_kdump}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%files kdump-debuginfo
%defattr(-,root,root)
%if "%{image_install_path}" != ""
/usr/lib/debug/%{image_install_path}/*-%{KVERREL}kdump.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}kdump
/usr/lib/debug/usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu}
%endif
%endif

%files kdump
%defattr(-,root,root)
/%{image_install_path}/vmlinux-%{KVERREL}kdump
/boot/System.map-%{KVERREL}kdump
#/boot/symvers-%{KVERREL}kdump.gz
/boot/config-%{KVERREL}kdump
%dir /lib/modules/%{KVERREL}kdump
/lib/modules/%{KVERREL}kdump/kernel
/lib/modules/%{KVERREL}kdump/build
/lib/modules/%{KVERREL}kdump/source
/lib/modules/%{KVERREL}kdump/extra
/lib/modules/%{KVERREL}kdump/updates
/lib/modules/%{KVERREL}kdump/weak-updates
/lib/modules/%{KVERREL}kdump/modules.scsi
/lib/modules/%{KVERREL}kdump/modules.libata
/lib/modules/%{KVERREL}kdump/modules.networking
%ghost /boot/initrd-%{KVERREL}kdump.img

%files kdump-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu}
/usr/src/kernels/%{KVERREL}kdump-%{_target_cpu}
%endif

# only some architecture builds need kernel-doc

%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%endif

%changelog
* Wed Aug 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-28m)
- update 2.6.21.7
- update sched-cfs-v2.6.21.7-v19.patch
- update ivtv-0.10.5
- update unionfs-2.1
- update btrfs-0.7
- update nilfs-2.0-test3

* Sun Jul  8 2007 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.21-26m)
- modify Prereq: mkinitrd >= 6.0.9-3m
- modify kernel-headers(i686)
- modify kernel-doc

* Sun Jul  8 2007 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.21-25m)
- modify spec
- modify kernel-2.6.21-*.config
- remove Provides: alsa-driver

* Wed Jul  4 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-24m)
- add btrfs-0.5

* Tue Jul  3 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-23m)
- import fedora patch(rev 1.3241)

* Sat Jun 23 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-22m)
- Patch7: sched-cfs-v2.6.21.5-v18.patch

* Sat Jun 23 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-21m)
- Patch7: sched-cfs-v2.6.21.5-v17.patch
- Patch11: linux-2.6.21-utrace.mo.patch

* Fri Jun 22 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-20m)
- update 2.6.21.5
- update and enabled nilfs-2.0.0-test2
- update and enabled ivtv-0.10.3
- sync patch from Fedora(kernel-2.6.spec(rev 1.3234)
- backport drm : support Intel G33, Q33, and Q35 chipsets.

* Sat Jun  9 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-19m)
- update 2.6.21.4

* Thu Jun  7 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-18m)
- backport DRM
- fix x86_64 config

* Thu Jun  7 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-17m)
- update alsa-1.0.14
- update any patches

* Sat May 26 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-16m)
- merge from TSUPPA4RI-branch
- update any patches

* Fri May 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-15m)
- update 2.6.21.3

* Wed May 23 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-14m)
- import any patch from Fedora

* Wed May 23 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-13m)
- update backport cpufreq patches 
-- Patch3: cpufreq-backport1.patch
-- Patch4: cpufreq-backport2.patch
- update backport XFS patche
-- Patch1480: xfs-backport.patch

* Tue May 22 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-12m)
- backport XFS patches 
-- Patch1480: xfs-propogate-return-codes-from-flush-routines.patch
-- Patch1481: xfs-fix-race-condition-xfs_write.patch
-- Patch1482: xfs-null-file-problem.patch
-- Patch1483: xfs-fix-race-condition-xfs_write-dmapi.patch
-- Patch1484: xfs-add-lockdep-support.patch

* Mon May 21 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-11m)
- fix ReiserFS warning 
-- linux-2.6-reiserfs-suppress-lockdep.patch
-- reiserfs-possible-null-pointer-dereference.patch
- import any patch from fc 
- cleanup spec

* Sat May 19 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-10m)
- import any patch from fc 

* Wed May 16 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-9m)
- update reiser4-patch
- update ipw3945-1.2.0 patch
- update ALSA-1.0.14-rc4
- update swsuspend-2.2.9.16

* Tue May 15 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.21-8m)
- enable Momonga boot logo on
  i586, i686-xen, i686, ppc64-kdump, ppc64, x86_64-kdump, x86_64-xen and x86_64
  (set "# CONFIG_LOGO_LINUX_CLUT224 is not set")

* Tue May 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-7m)
- import any patch from Fedora
- update madwifi-hal-0.9.30.13

* Fri May 11 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-6m)
- import any patch from Fedora
- cleanup spec 

* Mon May  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-5m)
- Patch11: linux-2.6.21-utrace.patch
- modified spec at %post: *FC* -> *mo* in link name setting for devel packages 
- do not appy kdb patches --- build_kdb set to 0

* Sun May  6 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-4m)
- update KDB-4.4 
- update unionfs-2.6.21-u2
- update software-suspend-2.2.9.13-2.6.21-rc7
- update reiser4(2.6.21-mm1)
- initial support ps3
-- boot has not been done yet

* Mon Apr 30 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-3m)
- update nouveau-drm.patch
- support kvm-21

* Sun Apr 29 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-2m)
- update 2.6.21.1
- CONFIG_SECURITY_CAPABILITIES=y 
-- capability.ko was need by named

* Thu Apr 26 2007 Shigeru Yamazaki <muradaikan@momonnga-linux.org>
- (2.6.21-1m)
- update source

* Wed Apr 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.7.2m)
- update reiser4 patch(2.6.21-rc7-mm1) 

* Wed Apr 18 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.7.1m)
- update 2.6.21-RC7
- update reiser4 patch(2.6.21-rc6-mm1) 

* Mon Apr  9 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.21-0.6.3m)
- -CONFIG_SECURITY_CAPABILITIES=y +CONFIG_SECURITY_CAPABILITIES=m
  for prepare about rlocate

* Mon Apr  9 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.21-0.6.2m)
- enable CONFIG_IKCONFIG=y and CONFIG_IKCONFIG_PROC=y for /proc/config.gz

* Fri Apr  6 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.6.1m)
- Patch0: patch-2.6.21-rc6
- Patch 11: linux-2.6.21-rc6-utrace.patch
- update Patch12: nouveau-drm.patch

* Thu Apr  5 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.5m)
- Source2400: madwifi-hal-0.9.30.10-current.tar.bz2 (r2249-20070329)
- Patch1460: linux-2.6.21-rc5-u1 for unionfs

* Fri Mar 30 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.4m)
- Source2400: madwifi-0.9.3.tar.bz2

* Wed Mar 28 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.3m)
- Patch11: linux-2.6.21-rc5-utrace.patch

* Tue Mar 27 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.2m)
- update config files

* Mon Mar 26 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.5.1m)
- Patch0: patch-2.6.21-rc5

* Sat Mar 24 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.4m)
- Patch1460: linux-2.6.21-rc4-u2.diff.gz
- Source2400: madwifi-ng-r2210-20070324

* Thu Mar 22 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.3m)
- Patch1460: linux-2.6.21-rc4-u1.diff.gz 

* Sun Mar 18 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.4.2m)
- use straight copies of config files from fc7 development and 
  slightly modify to suit Momonga Linux
- modified spec to accommodate the changes in spec files

* Sat Mar 18 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.21-0.4.1m)
- update 2.6.21-rc4
-- add config CONFIG_ACPI_IBM_BAY=y

* Sun Mar 11 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.6m)
- revise kernel-2.6.21-x86_64.config for IPTABLES

* Sat Mar 10 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.5m)
- Patch1460: linux-2.6.21-rc3-u1.diff.gz

* Thu Mar  9 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.4m)
- revive Patch1400: squashfs3.2-patch.bz2
  squashfs3.2-r2.tar.gz doesn't patch the source ... orz

* Thu Mar  8 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.3m)
- support Reiser4 FileSystem

* Thu Mar  8 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.2m)
- revive forgotten squashfs in config files

* Wed Mar  7 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.3.1m)
- Patch0: patch-2.6.21-rc3
- enabled all PATA drivers as modules
- enabled unionfs

* Thu Mar  1 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.2.1m)
- Patch0: patch-2.6.21-rc2

* Wed Feb 21 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.21-0.1.1m)
- Patch0: patch-2.6.21-rc1
- Patch11: linux-2.6.21-rc1-utrace.patch
- removed reiser4 patches

* Tue Feb 20 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-3m)
- Patch1: patch-2.6.20.1 (CVE-2007-0772)

* Mon Feb 12 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-2m)
- Patch30: Suspend2 2.2.9.7
- Source2400: madwifi-ng-r2100-20070210

* Mon Feb  5 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-1m)
- Source0; linux-2.6.20

* Thu Feb  1 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.7.1m)
- Patch0: patch-2.6.20-rc7

* Thu Jan 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.20-0.6.1m)
- Patch0: patch-2.6.20-rc6

* Sat Jan 13 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.5.1m)
- Patch0: patch-2.6.20-rc5
- update Patch1740

* Mon Jan 08 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.4.1m)
- Patch0: patch-2.6.20-rc4

* Tue Jan 02 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.3.1m)
- Patch0: patch-2.6.20-rc3
- updated Patch11: linux-2.6-utrace.patch

* Mon Dec 25 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.2.1m)
- Patch0: patch-2.6.20-rc2
- updated Patch11: linux-2.6-utrace.patch 

* Sat Dec 23 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.1.7m)
- update config files for x86_64

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.6m)
- modify i586 and i686 configs based on 2.6.19-1.2885.fc7
- ATA/ATAPI/MFM/RLL support is still enabled, take care

* Wed Dec 20 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.20-0.1.5m)
- Support Reiser4
-- patch 1410-1436

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.4m)
- modify following sections of i586 and i686 configs
  IPVS application helper
  Core Netfilter Configuration
  IP: Netfilter Configuration
  Hardware Monitoring support
  Character devices
  Miscellaneous USB options
  USB Host Controller Drivers

* Wed Dec 20 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.20-0.1.3m)
- modify i586 and i686 configs to enable booting from SATA disks

* Wed Dec 20 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.20-0.1.2m)
- change i686 configs for build on i686 archs

* Sun Dec 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.20-0.1.1m)
- Patch0: patch-2.6.20-rc1
- patches from fc7 kernel package
- build on x86_64 arch only and others will not build yet

* Wed Dec 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-3m)
- Patch1: patch-2.6.19.1

* Sun Dec 10 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-2m)
- update spec and provide kernel-headers package
- Patch2: patch-2.6.19-git18

* Thu Nov 30 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-1m)
- Source0; linux-2.6.19

* Mon Nov 20 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.6.3m)
- modify config file
  # CONFIG_PREEMPT_NONE is not set
  CONFIG_PREEMPT_VOLUNTARY=y
  # CONFIG_CRASH_DUMP is not set
  CONFIG_CC_STACKPROTECTOR=y
  CONFIG_CC_STACKPROTECTOR_ALL=y
  CONFIG_HZ_250=y
  CONFIG_SSFDC=m 
  CONFIG_DLM=m
  CONFIG_CRYPTO_TWOFISH_X86_64=m
  
* Sat Nov 18 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.19-0.6.2m)
- enable EXT4 FS in config files
  patch for config files is below
  -# CONFIG_EXT4DEV_FS is not set
  +CONFIG_EXT4DEV_FS=m
  +CONFIG_EXT4DEV_FS_XATTR=y
  +CONFIG_EXT4DEV_FS_POSIX_ACL=y
  +CONFIG_EXT4DEV_FS_SECURITY=y
  +CONFIG_JBD2=m
  +# CONFIG_JBD2_DEBUG is not set
  and only kernel-2.6.19-x86_64-xen.config is changed below
  -CONFIG_EXT4DEV_FS=y
  +CONFIG_EXT4DEV_FS=m
  -CONFIG_JBD2=y
  +CONFIG_JBD2=m  

* Sat Nov 18 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.6.1m)
- Patch0: patch-2.6.19-rc6

* Sat Nov 11 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.5.2m)
- enable nilfs-1.0.14

* Thu Nov 09 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.5.1m)
- Patch0: patch-2.6.19-rc5

* Wed Nov 08 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.4.2m)
- use smp config for i586 i686 and x86_64
- test build for x86_64 ONLY

* Tue Nov  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.19-0.4.1m)
- Patch0: patch-2.6.19-rc4

* Sat Oct 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-2m)
- Patch0: patch-2.6.19-rc3

* Fri Sep 22 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-1m)
- Source0: linux-2.6.18

* Sat Sep 16 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.7.2m)
- revised config files for x86_64

* Wed Sep 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.7.1m)
- Patch0: patch-2.6.18-rc7

* Wed Sep 6 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.6.2m)
- revised config files for x86_64
  enabled NUMA for smp
    CONFIG_NUMA=y
    CONFIG_K8_NUMA=y
    CONFIG_X86_64_ACPI_NUMA=y
    CONFIG_NUMA_EMU=y
    CONFIG_ACPI_NUMA=y

* Tue Sep 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.6.1m)
- Patch0: patch-2.6.18-rc6

* Tue Aug 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.4m)
- set NTFS_FS=m and NTFS_RW=y in config files 

* Tue Aug 22 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.3m)
- update ix86 config files

* Thu Aug 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.2m)
- revive some patches that were removed at 2.6.18-0.4.1m

* Sat Aug 12 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.4.1m)
- built without xen, reiser4, nilfs, ipw3945

* Mon Jul 31 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.4m)
- restructure packaging to follow trunk kernel

* Fri Jul 21 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.18-0.2.3m)
- enable Reiser4 FS
- Patch1001: reiser4-for-2.6.17-1.patch.gz
- Patch1003: reiser4-vs-zoned-allocator.patch
- Patch1004: reiser4-get_sb_dev-fix.patch
- Patch1005: make-copy_from_user_inatomic-not-zero-the-tail-on-i386-vs-reiser4.patch
- Patch1010: reiser4-2.6.17-writeback_control.patch

* Wed Jul 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.2m)
- Patch530: linux-2.6.18-dbus.patch
- update ix86 config files

* Sun Jul 16 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.2.1m)
- Patch1: patch-2.6.18-rc2
- only x86_64 config files are updated
- xen and unionfs are disabled

* Sat Jul 08 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.18-0.1.1m)
- Patch1: patch-2.6.18-rc1

* Fri Jul 06 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-6m)
- Patch0: patch-2.6.17.4

* Wed Jul 05 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.17-5m)
- patch : apply patch2202 -p1 ifarch %%i686 for unionfs build
- config: delete CONFIG_SCSI_ADVANSYS only i686
- config: add missing config only i686

* Fri Jun 30 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-4m)
- attempt to revive xen - not complete and still experimental
- tested on x86_64 arch only 
- patches copied from FC6

* Sat Jun 24 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.17-3m)
- update squashfs3.0-patch.bz2

* Tue Jun 20 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-2m)
- Patch0: patch-2.6.17.1

* Mon Jun 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-1m)
- built with x86_64 spec only

* Wed Jun 15 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.6.2m)
- Source2500: unionfs-1.2
- unionfs source is merged into kernel source tree for building

* Wed Jun  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.6.1m)
- patch0: prepatch-2.6.17-rc6

* Sat May 27 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.5.1m)
- patch0: prepatch-2.6.17-rc5

* Thu May 11 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.17-0.3.2m)
- add linux-2.6.16-snd_cs4281-alsa-1.0.11.patch
  https://bugtrack.alsa-project.org/alsa-bug/view.php?id=1976
- import alsa-driver-1.0.11.via82xx.diff.gz from Slackware
  https://bugtrack.alsa-project.org/alsa-bug/view.php?id=2067

* Sat Apr 29 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.3.1m)
- Prepatch: patch-2.6.17-rc3
- linux26-2.6.16-usagi-20060423
- madwifi ng-r1523-20060423
- Source3090: Suspend2-2.2.5-for-2.6.17-rc2 not applied 

* Fri Apr 21 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.2.1m)
- Prepatch: patch-2.6.17-rc2
- Source3090: Suspend2-2.2.4.1-for-2.6.17-rc1 patch temporarily not applied
- edit spec to include Module.symvers
- remove Source3091: 582-refrigerator.momo3
- remove Source3092: 201-ati-agp.momo2
- remove Source3093: 209-get-module-list.momo1
- remove Source3094: 210-workthreads.momo1

* Fri Apr  7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.4m)
- Patch50: linux26-2.6.16-usagi-20060406.patch.gz

* Thu Apr  6 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.17-0.1.3m)
- update {i686,i686-smp,i586,i586-smp}.config for iptables

* Wed Apr  5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.2m)
- update x86_64 config files for iptables

* Wed Apr  5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.17-0.1.1m)
- Prepatch: patch-2.6.17-rc1
- add CONFIG_SCSI_ADVANSYS=m to x86_64 and ppc config files
- add CONFIG_NETFILTER_XTABLES=m and related settings to i586/i686 config files

* Tue Apr  4 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.16-5m.dev)
- import advansys patches from Fedora Core devel
 - linux-2.6-scsi-advansys-enabler.patch
 - linux-2.6-scsi-advansys-pcitable.patch
- add CONFIG_SCSI_ADVANSYS=m to {i686,i686-smp,i586,i586-smp}.config

* Sun Apr  2 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-4m.dev)
- Source3090: suspend2-2.2.4-for-2.6.16.tar.bz2

* Fri Mar 31 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-3m)
- Patch1001: reiser4-for-2.6.16-1.patch.gz 

* Sun Mar 26 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-2m)
- Source: 2.6.16.1

* Sun Mar 26 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-1m)
- unionfs is not included in this version
- config files available only for x86_64 architecture

* Tue Mar 14 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.6.1m)
- Prepatch: patch-2.6.16-rc6

* Wed Mar 01 2006 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.6.16-0.5.2m)
- revised kernel.spec

* Tue Feb 28 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.5.1m)
- Prepatch: patch-2.6.16-rc5
- Source2400: madwifi-ng-r1457-20060228

* Thu Feb 23 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.4.2m)
- experimenting the Completely Fair Queuing (CFQ) scheduler as 
  the default algorthim:
  CONFIG_DEFAULT_AS=y             -> CONFIG_DEFAULT_AS is not set 
  CONFIG_DEFAULT_CFQ is not set   -> CONFIG_DEFAULT_CFQ=y
- edit config files:
  CONFIG_HZ=250                   -> CONFIG_HZ=1000
  CONFIG_HZ_250=y                 -> CONFIG_HZ_250 is not set
  CONFIG_HZ_1000 is not set       -> CONFIG_HZ_1000=y
  CONFIG_PM_LEGACY is not set     -> CONFIG_PM_LEGACY=y
- Above work was inspired by ichro. Thank you. 
- Source2500: unionfs-1.1.3.tar.gz

* Sat Feb 18 2006  Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.4.1m)
- Prepatch: patch-2.6.16-rc4
- Source2500: unionfs-1.1.2.tar.gz
- Source2600: nilfs-1.0.6.tar.bz2
- Patch2200: unionfs-mkdir-unionfs112.patch
- remove Patch3008: linux-2.6.14-unionfs-ppc.patch

* Mon Feb 13 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.3.1m)
- Prepatch: patch-2.6.16-rc3

* Sun Feb 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.2.1m)
- Prepatch: patch-2.6.16-rc2
- experimenting NOT merging alsa-driver source

* Sat Feb 4 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.3m)
- edit spec and config files for SUSPEND2 (for build only)
  SUSPEND2 functionality is not tested

* Fri Jan 27 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.2m)
- Patch50: linux26-2.6.15-usagi-20060201.patch.gz
- Patch600: kernel-shut-the-gcc41warning.patch
  only for gcc4.1: set use_gcc41 1 to apply patch
- Source2600: nilfs-1.0.5.tar.bz2

* Thu Jan 19 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.16-0.1.1m)
- prepatch: patch-2.6.16-rc1
- Alsa Driver: alsa-1.0.11rc2
- Source2600: nilfs-1.0.4 and not NoSource
- Source3090: software-suspend-2.2-for-2.6.15.1
- Patch1001: reiser4-for-2.6.15-1
- remove Patch1401
- update configs for 2.6.16
  almost straight copies with some new alsa modules

* Tue Jan 17 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-5m)
- update kernel-2.6.15-x86_64-smp.config

* Thu Jan 12 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-4m)
- Patch50: linux26-2.6.15-usagi-20060111.patch.gz
- Source3090: software-suspend-2.2-rc16-for-2.6.15
- removed /lib/modules/$KernelVer/build/include/config/MARKER from packaging 

* Sat Jan 7 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-3m)
- Patch100: linux-2.6-gcc41.patch
- Patch2008: linux-2.6.14-sis5513.patch
- x86_64 is added in for building madwifi and unionfs

* Thu Jan 5 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-2m)
- kdb_kernel_ver 2.6.15
- Patch50: linux26-2.6.15-usagi-20060105.patch.gz

* Wed Jan 4 2006 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-1m)
- Source0: linux-2.6.15

* Mon Jan 02 2006 mutecat <mutecat@momonga-linux.org>
- (2.6.15-0.7.7m)
- arrange ppc.

* Sat Dec 31 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.6m)
- use /sbin/modinfo instead of /sbin/modinfo.old -- copied from 2.6.14-13m spec by takahata

* Thu Dec 29 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.15-0.7.5m)
- modify {i686, i686-smp, i586, i586-smp}.config for ALSA
- add kernel-2.6.15-rc1-fix-alsa-bad-page.patch
  http://lkml.org/lkml/2005/11/19/82

* Wed Dec 28 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.15-0.7.4m)
- add CONFIG_PM_LEGACY=y to {i686, i686-smp, i586, i586-smp}.config

* Tue Dec 27 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.3m)
- Source3090: software-suspend-2.2-rc15-for-2.6.15-rc7
- Patch50: linux26-2.6.15-rc7-usagi-20051226.patch.gz
- Source2400: madwifi-ng-current.tar.gz
   IF building fails with "missing Makefile.cpu" comment out for madwifi-ng-current.tar.gz 
   and use madwifi-cvs-current.tar.bz2 instead -- error will occur when building 2.6.15-0.7.2m
   has been skipped

* Mon Dec 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.2m)
- edit spec to package Makefile.cpu

* Sun Dec 25 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.7.1m)
- prepatch: patch-2.6.15-rc7

* Fri Dec 23 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.15-0.6.2m)
- update config files --- new modules are "not set" and ppc and x86 may not build
- reiser4 patch not applied
- Source3090: software-suspend-2.2-rc14-for-2.6.15-rc5
- Patch50: linux26-2.6.15-rc6-usagi-20051222.patch.gz

* Tue Dec 20 2005 Shigeru Yamazaki <muradaikan@momonga-lilnux.org>
- (2.6.15-0.6.1m)
- prepatch: patch-2.6.15-rc6
- Alsa Driver: alsa-1.0.10

* Thu Dec 15 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-12m)
- Source: 2.6.14.4
- Source3090: software-suspend-2.2-rc14-for-2.6.14

* Sat Nov 26 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.14-11m)
- changed config files
-  Source28: kernel-2.6.14-x86_64.config
-  Source29: kernel-2.6.14-x86_64-smp.config

* Sat Nov 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-10m)
- Source: 2.6.14.3
- Source3090: software-suspend-2.2-rc13-for-2.6.14

* Wed Nov 23 2005 mutecat <mutecat@momonga-linux.org>
- (2.6.14-9m)
- arrange ppc
- add linux-2.6.14-usbaudio-ppc.patch from linux-usb-devel with arrange
- add linux-2.6.14-tea575x-ppc.patch
- add linux-2.6.14-unionfs-ppc.patch

* Tue Nov 22 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-8m)
- Source3090: software-suspend-2.2-rc12-for-2.6.14
- Source2300: hostap-driver-0.4.7.tar.gz
- Source2400: madwifi-cvs-current.tar.gz
- Source2600: nilfs-1.0.3.tar.bz2
- Patch50: linux26-2.6.14-usagi-20051121.patch.gz

* Mon Nov 14 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-7m)
- add config files in attempt to compile additional packages
  Source26: kernel-2.6.14-ppc.config
  Source27: kernel-2.6.14-ppc-smp.config
  Source28: kernel-2.6.14-x86_64.config
  Source29: kernel-2.6.14-x86_64-smp.config
- changed config files for i686 and i586, and their smp

* Sat Nov 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-6m)
- Patch531: linux-2.6.14-dbus-smp.patch -- see if x86_64 can be built

* Sat Nov 12 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-5m)
- Source2600: nilfs-1.0.2.tar.bz2
- update Patch531 to linux-2.6.14-dbus-non-ix86.patch

* Sat Nov 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-4m)
- Source: 2.6.14.2
- Patch1001: reiser4-for-2.6.14-1.patch.gz
- Patch1002: reiser4-export-pagevec-funcs.patch
- CONFIG_REISER4_FS=m
- Source3090: software-suspend-2.2-rc9-for-2.6.14

* Sun Nov 6 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-3m)
- Patch530: linux-2.6.14-dbus.patch

* Tue Nov 1 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-2m)
- enable CODA_FS

* Fri Oct 28 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-1m)
- source 2.6.14

* Tue Oct 25 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.3m)
- Patches 70, 71, and 72: kdb_kernel_ver 2.6.14-rc5
- edit spec to accommodate HIMEM64G properly for related config files

* Mon Oct 24 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.2m)
- Patch50: linux26-2.6.14-rc5-usagi-20051024.patch.gz 
    attempt only and not applied
- Source2300: hostap-driver-0.4.5.tar.gz
- Source2500: unionfs-1.0.14
- Source2600: nilfs-1.0.1.tar.bz2

* Fri Oct 21 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.5.1m)
- prepatch 2.6.14-rc5

* Sat Oct 15 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.4.2m)
- update madwifi driver

* Wed Oct 12 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.4.1m)
- prepatch 2.6.14-rc4

* Sun Oct 9 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.3.1m)
- prepatch 2.6.14-rc3
- Source3090: software-suspend-2.2-rc8-for-2.6.14-rc3
   but NOT applied as it builds ext3.ko with unknown symbol

* Wed Sep 28 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.2.3m)
- use KSRC instead of KERNELPATH at nilfs (thanks to Dai san)
- change Patch1300 about function refrigerator part
- update unionfs to 20050927-1408

* Mon Sep 26 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.14-0.2.2m)
- add Source2600: http://www.osrg.net/nilfs/nilfs-1.0.0.tar.bz2
- change nilfs source file for conflicts with swsusp2(?)
- change nilfs Makefile < unionfs Makefile
- make Patch1300: nilfs-1.0.0.patch

* Fri Sep 23 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.2.1m)
- pretach 2.6.14-rc2
- build for only i586, i686, i586-smp, and i686-smp. Other configs not ready.

* Sat Sep 17 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.14-0.1.1m)
- prepatch 2.6.14-rc1
- source to build drivers for ipw2100 and ipw2200, and ieee80211 subsystem 
  are added in from prepatch-2.6.14-rc1
- remove the following for the above reason:
   Source 135, 136, 2300. Patch 1202, 1203, 1204, and 2003-7.
- Source2400: madwifi-cvs-snapshot-2005-09-14.tar.bz2
- Patch530: linux-2.6.14-dbus.patch
- build only i586, i686, i586-smp, and i686-smp. Other configs not ready.
- spec file has many lines that may no longer be needed.

* Sun Sep 11 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-3m)
- source 2.6.13.1
- Source3090: software-suspend-2.2-rc6-for-2.6.13
- Patch700: linux-2.6.13-mppe-mppc-1.3.patch.gz
- hostap-driver with Source2300: hostap-driver-0.4.4.tar.gz
- edit spec to have "srcversion" at some lines where "kversion" was specified

* Sun Sep 4 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-2m)
- ipw2100 and ipw2200 drivers - not sure if they work properly
- Patch1202: ipw2100-1.1.0-linux2613-momonga.patch - remove redefinition
- Patch1203: ipw2200-1.0.2-linux2613-momonga.patch
- Source136: ipw2200-1.0.2 - changed from 1.0.6 to sync with ipw2100-1.1.0
- SWSUSP2: apply software-suspend-2.2-rc5-for-2.6.13

* Wed Aug 31 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.13-1m)
- source 2.6.13
- SWSUSP2: apply software-suspend-2.2-rc4-for-2.6.13
- Temporarily skip applying Patch50: linux26-2.6.12-usagi-20050829.patch.gz
- Patch1200: linux-2.6.13-reiser4.patch (!!!module NOT in working order!!!)
   maybe needed until Reiserfs4 publishes a patch for 2.6.13
- Alsa driver 1.0.10rc1
- Skip building unionfs

* Sun Aug 28 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-7m)
- SWSUSP2: return to apply stable software-suspend-2.1.9.5-for-2.6.12
- Patch530: linux-2.6.12.5-dbus.patch

* Fri Aug 26 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-6m)
- source 2.6.12.5
- kernel config files for 2.6.12.5 are straight copies of 2.6.12.4 without alteration
- SWSUSP2: apply stable software-suspend-2.2-rc2-for-2.6.13-rc7
- Source2300 hostap-driver 0.4.1
- Source2400 madwifi-cvs-snapshot 2005-08-26
- Patch50 linux26-2.6.12-usagi-20050815.patch.gz
- kdb kernel-ver 2.6.12

* Sun Aug 22 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.12-5m)
- update squashfs-2.2
- update unionfs-1.0.13
-  build fix unionfs

* Fri Aug 12 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.12-4m)
- enable ppc.
-  add kernel-2.6.12.4-ppc.config, kernel-2.6.12.4-ppc-smp.config
-  cancel Patch3004
-  add Patch3005: fix for ``unknown symbol csum_ipv6_magic''

* Thu Aug 11 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-3m)
- Temporarily skip applying software-suspend-2.1.9.12-for-2.6.13-rc5
  to build package without halting and having to hit Enter key.

* Thu Aug 11 2005 Ryu SASAOKA <ryu@momonga-linux.org>
- (2.6.12-2m)
- enable x86_64. 
-  add kernel-2.6.12.4-x86_64.config, kernel-2.6.12.4-x86_64-smp.config
-  cancel patch100 (linux-2.6.10-x86_64-avoid-redefined-macros.patch)

* Tue Aug 9 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.12-1m)
- kernel source is linux-2.6.12.4
- tentatively builds only i586 i686 (not sure about their smp's)
- Patch50: linux26-2.6.12-usagi-20050807.patch.gz
- Patch500: linux-2.6.12-nonintconfig.patch
- Patch530: linux-2.6.12-dbus.patch
- Applying software-suspend-2.1.9.12-for-2.6.13-rc5 halts at
    230-refrigerator-to-try_to_freeze.patch and hit Enter to proceed (suman!)
- ALSAbasever 1.0.9b
- ieee1394 - use source in the kernel source
- IPW2*00 is not set in configs


* Sun Jul 17 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.10-41m)
- remove any patch. because downgrade binutils
- Patch98: linux-2.6-seg-5.patch
- Patch99: linux-2.6-colinux-seg.patch

* Thu Jun 14 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-40m)
- add Patch100: linux-2.6.10-x86_64-avoid-redefined-macros.patch
- modified configs for x86_64.
- above fixes are just for x86_64, thus it would affect x86_64 only.

* Tue Jun  7 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (2.6.10-39m)
- add binutils-2.90.16.0.3 assembler patch.

* Tue May 10 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-38.1m)
- add Patch4000: http://www.kernel.org/pub/linux/kernel/people/jgarzik/libata/old/2.6.10-bk9-libata-dev1.patch.bz2

* Fri May  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-38m)
- merge madwifi.
- merge unionfs.

* Thu Apr 28 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-37m)
- add Patch1100: squashfs2.1-patch.bz2
- add CONFIG_SQUASHFS=m into all kernel-2.6.10*.config

* Fri Apr 15 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-36m)
- disable CONFIG_4KSTACKS
- disable buildxen temporarily

* Sun Apr 10 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-35m)
- modify *.config with compatibile feature before 2.6.10-26m

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-34m)
- revised linux-2.6.10-xen.patch so that reiser4 potrion is built properly.
- CONFIG_AIC7XXX_PROBE_EISA_VL does not necessary.

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-33m)
- revised spec for x86_64 and ppc.

* Thu Apr 07 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-32m)
- xen.patch was extructed from xen-unstable-src.tgz.

* Mon Apr 04 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-31m)
- patchies including SWSUPS2, workqueue and coLinux are always applied.
- in the case of i686-smp, CONFIG_HIGHMEM64G is sellectable by specopt.

* Sat Apr 02 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-30m)
- add xen from kernel-2.6.10-1.1162_FC4/kernel-2.6.spec
- - add Patch450: linux-2.6.10-xen.patch
- - add Patch452: linux-2.6.9-xen-compile.patch
- - add Patch453: linux-2.6.9-xen-agpgart.patch
- - add Source37: kernel-2.6.10-i686-xen0.config
- - add Source38: kernel-2.6.10-i686-xenU.config
- rename config file number 37->30, 38->31
- add %%{SOURCE30} %%{SOURCE31} at 'mkdir configs' part
- update Patch452: linux-2.6.10-xen-compile.patch
- update Patch453: linux-2.6.10-xen-agpgart.patch

* Tue Mar 22 2005 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.10-29m)
- fixed PPP Server Denial of Service Vulnerability (CAN-2005-0384)

* Mon Mar 14 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-28m)
- modify ppc config

* Mon Mar 14 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.10-27m)
- fix ppc build. sorry... orz

* Tue Mar  8 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-26m)
- config files are fixed.

* Sun Mar  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-25m)
- use gcc_3_2 for coLinux.

* Sun Mar  6 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-24m)
- modified kernel-*.config. take care.

* Sat Mar  5 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-23m)
- simplified.

* Sat Mar  5 2005 mutecat <mutecat@momonga-linux.org>
- (2.6.10-22m)
- arrange ppc without patch 3005, 3006
- add FB driver
  CONFIG_FB_RADEON_OLD=y
  CONFIG_FB_RADEON=y
  CONFIG_FB_RADEON_I2C=y
  CONFIG_FB_ATY128=y

* Thu Mar  3 2005 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.10-21m)
  reiser4: update to 2.6.10-2

* Wed Mar  2 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.6.10-20m)
- add CONFIG_TMPFS_XATTR=y CONFIG_TMPFS_SECURITY=y
- for ppc CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=1

* Thu Feb 24 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-19m)
- CONFIG_PNPACPI is turned off.
- revised colinux-0.6.2-2.6.10.patch.
- %%{buildco} is always turned off other than %%{ix86}.

* Sat Feb 20 2005 minakami <minakami@momonga-linux.org>
- (2.6.10-18m)
- coLinux 0.6.2 support
- add new Source40: config-i586-co
- add new Source41: config-i686-co
- add new Source42: config-p4-co
- add new Source43: config-cm-co
- add new Source44: config-k7-co
- add new Source45: config-k8-co
- add new Source46: config-co-generic
- add new Patch93: colinux-0.6.2-2.6.10.patch
- add new Patch94: colinux-0.6.2-2.6.10-momonga.patch

* Sat Feb 19 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-17m)
- CONFIG_USB_HID, CONFIG_USB_KBD and CONFIG_USB_MOUSE is turned on.

* Wed Feb 16 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (2.6.10-16m)
- add MEGARAID driver
  CONFIG_MEGARAID_NEWGEN=y
  CONFIG_MEGARAID_MM=m
  CONFIG_MEGARAID_MAILBOX=m
- add ppc patch from FC-devel.
- ppc-config renew.
  FIXME: ip6t_REJECT.ko ip6_conntrack.ko ip6_conntrack_ftp.ko unresolve symbols.

* Tue Jan 18 2005 Toru Hoshina <t@momonga-linux.org>
- (2.6.10-15m)
- rebuild on x86_64.

* Mon Jan 17 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-14m)
- add Patch700: http://www.polbox.com/h/hs001/linux-2.6.10-mppe-mppc-1.2.patch.gz
- set CONFIG_PPP_MPPE_MPPC=m in config-generic

* Fri Jan 14 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-13m)
- update to alsa-1.0.8
- add rm -f %%{swsusp2name}/950-alsa-fixes-already-in-bk

* Sat Jan 08 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-12m)
- add Patch580: 2.6.10-mm1-brk-locked.patch 
  from http://marc.theaimsgroup.com/?l=linux-kernel&m=110512844202355
  (VTS:00059)

* Fri Jan 07 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-11m)
- add new Patch1002: reiser4-export-find_get_pages_tag.patch

* Fri Jan 07 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-10m)
- update reiser4 patch
- delete Patch1002: reiser4-dont-use-shrink_dcache_anon.patch
- add 'chmod 644 drivers/scsi/a100u2w.c'
  for cp (prepare for madwifi and etc drivers)

* Thu Dec 30 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-9m)
- update usagi patch

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-8m)
- update madwifi driver (import from kernel24.spec)
- add 'CONFIG_ATHEROS=m', 'CONFIG_ATHEROS_HAL=m', 'CONFIG_ATHEROS_RATE=m'
  and 'CONFIG_NET80211=m' into config-generic
- set '# CONFIG_ATHEROS_HAL is not set', '# CONFIG_ATHEROS_RATE is not set' into config-generic
  reason:
  $ /sbin/modinfo.old -l /var/tmp/kernel-2.6.10-root/lib/modules/2.6.10-8m/kernel/drivers/net/wireless/_ath_hal/ath_hal.ko
  -> "Proprietary"
- comment out all making madwifi drivers part:
  because if we include madwifi drivers, kernel packages shall be Nonfree

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-7m)
- fix Source0 URI
- add 'CONFIG_PCCARD=m' and '# CONFIG_PCMCIA_OBSOLETE is not set' 
  into config-generic (thanks to tom san)
- add 'CONFIG_PCCARD=m', '# CONFIG_PCMCIA_OBSOLETE is not set', 
  'CONFIG_CARDBUS=y', 'CONFIG_I82365=m', and 'CONFIG_PCMCIA_PROBE=y'
  into config-ppc and config-ppc-smp
- why config-ppc and config-ppc-smp is same file?

* Tue Dec 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-6m)
- roll back software-suspend patch to 2.1.5.10-for-2.6.10-rc3
  cause 2.6.10-5m (software-suspend patch to 2.1.5.10-for-2.6.10)
  can not work hibernate my machine in progress 'Thawing other processors',
  but 2.6.10-4m (software-suspend patch to 2.1.5.10-for-2.6.10-rc3) can hibernate
- add Patch3092: 201-ati-agp.momo2
  from 2.1.5.10-for-2.6.10 one and fix below
  http://lists.berlios.de/pipermail/softwaresuspend-devel/2004-December/001382.html
- add Source3093: 209-get-module-list.momo1 from 2.1.5.10-for-2.6.10 one
- add Source3094: 210-workthreads.momo1 from 2.1.5.10-for-2.6.10 one
- ok, I can hibernate by 2.6.10-6m
- set '# CONFIG_LOGO_LINUX_CLUT224 is not set' in config-generic
  for enable Momonga boot logo (thanks to nakai san)

* Mon Dec 27 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-5m)
- update software-suspend patch to 2.1.5.10-for-2.6.10
- delete Source3094: 201-ati-agp.momo1 (included to swsusp2)
- delete Patch1200: linux-2.6.10-cx88-video-fake-arg.patch (included to swsusp2)
- rm kdb patches from software-suspend (momomai #100)

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-4m)
- update kdb patch to 2.6.10, but not tested (default disable)
- info: patch92 was used by prepare for dbus patch
- add Patch1002: reiser4-dont-use-shrink_dcache_anon.patch from 2.6.10-rc3-mm1
  for delete WARNING: /lib/modules/2.6.10-3m/kernel/fs/reiser4/reiser4.ko \
  needs unknown symbol shrink_dcache_anon
- update ipw2100 driver to 1.0.2
- update ipw2200 driver to 0.19
- update Patch2004: ipw2100-1.0.2-create_workqueue.patch
- update Patch2005: ipw2200-0.19-create_workqueue.patch
- info:
  %%{buildup} || %%{copper} || %%{pen4} || %%{amdk7} || %%{amdk8}
  was used buildup+buildsmp(default) and buildup only

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-3m)
- Patch2004 and Patch2005 apply ifarch *smp only

* Sun Dec 26 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-2m)
- update to software-suspend-2.1.5.10-for-2.6.10-rc3.tar.bz2
  cause 2.6.10-1m do not work swsusp2 my machine,
  stop in progress 'Doing atomic copy...'
- TODO: update Patch92: linux-2.6.9-swsusp-smp2.patch

* Sat Dec 25 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-1m)
- update to 2.6.10
  http://www.uwsg.indiana.edu/hypermail/linux/kernel/0412.3/0072.html
- update Source3091: 582-refrigerator.momo2
- update againt Source3091: 582-refrigerator.momo3
- add Source3092: 209-get-module-list.momo01
- update usagi patch and fix by hand
- update Patch500: linux-2.6.10-nonintconfig.patch
- update Patch530: linux-2.6.10-dbus.patch
- delete included Patch540: linux-2.6.6-online-resize.patch
- delete included Patch580: elf-loader-setuid-mo
- delete included Patch581: fix-aout-leak
- delete included Patch582: buffer-overrun-in-arch-x86_64-sys_ia32csys32_ni_syscall-sys32_vm86_warning.patch
- delete included Patch583: 2.6.10-rc3-decnet.patch
- delete included Patch584: gnupatch@41bf39b1RGfvOMInGewwDyzfcuL2OQ
- delete included Patch585: gnupatch@41b768d1ySHbfa7cUWDle8NjDT_02A
- delete included Patch2000:
  2.6.9-rc1/2.6.9-rc1-mm3/broken-out/scsi-qla2xxx-fix-inline-compile-errors.patch
- delete included Patch2010: security-fix-smbfs-2.6.9-ac3.patch
- add '# CONFIG_MODULE_SRCVERSION_ALL is not set' into config-generic
- add '# CONFIG_MEFFICEON is not set' into config-x86-generic
- add Source3093: 100-kdb-v4.4-2.6.9-rc2-common-1.momo1
  for s/TASK_ZOMBIE/EXIT_ZOMBIE/g , s/TASK_DEAD/EXIT_DEAD/g.
- add Source3094: 201-ati-agp.momo1
- add new Patch1200: linux-2.6.10-cx88-video-fake-arg.patch

* Wed Dec 22 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.10-0.3.1m)
- update to 2.6.10-rc3
- update swsusp2 patch
- update usagi patch
- update alsa patch

* Sun Dec 19 2004 mutecat <mutecat@momonga-linux.org>
- (2.6.9-22m)
- kossori

* Sat Dec 17 2004 mutecat <mutecat@momonga-linux.org>
- (2.6.9-21m)
- arrange ppc
- add Patch3000: linux-2.6.9-ppc.patch
- add Patch3001: linux-2.6.9-ppc-forc.patch
- add ppc config files

* Thu Dec 16 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-20m)
- add Patch585: gnupatch@41b768d1ySHbfa7cUWDle8NjDT_02A

* Thu Dec 16 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-19m)
- add Patch584: gnupatch@41bf39b1RGfvOMInGewwDyzfcuL2OQ

* Tue Dec 14 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-18m)
  update hostap-driver 0.3.0
  update ieee1394 rev 1240
  update ipw2200 0.17
  update reiser4 3
  update software-suspend 2.1.5.7

* Mon Dec 13 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-17m)
- add Patch583: 2.6.10-rc3-decnet.patch

* Mon Dec 13 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-16m)
- add Patch582: buffer-overrun-in-arch-x86_64-sys_ia32csys32_ni_syscall-sys32_vm86_warning.patch

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-15m)
- add i686 to basearch

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-14m)
- add Patch581: fix-aout-leak

* Sun Dec 12 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-13m)
- add Patch580: elf-loader-setuid-mo

* Sat Dec 11 2004 Masayuki SANO <nosanosa@momonga-linux.org>
- (2.6.9-12m)
- CONFIG_DRM_I915=m in config-generic
- BuildPreReq: module-init-tools

* Tue Nov 30 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-11m)
  support reiser4: patch 1001
  update ipw2100 1.0.1
  update ipw2200 0.15
  update ieee1394 rev 1234

* Sun Nov 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-10m)
- add Patch2010: security-fix-smbfs-2.6.9-ac3.patch from 2.6.9-ac3

* Thu Nov  4 2004 Shotaro Kamio <skamio@momonga-linux.org>
- (2.6.9-9m)
- add patch570 for compilation of NVIDIA driver

* Tue Nov 02 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-8m)
- delete dup obsoletes
- update usagi patch

* Thu Oct 28 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-7m)
- delete i2c

* Wed Oct 27 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-6m)
- re-add Patch91: linux-2.6.9-swsusp-smp.patch
  re-add Patch2004: ipw2100-0.56-create_workqueue.patch
  re-add Patch2005: ipw2200-0.12-create_workqueue.patch
  for fix build miss about up+smp (default)

* Sun Oct 24 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-5m)
- delete Patch91: linux-2.6.9-swsusp-smp.patch
- add apply swsusp2 patch %%{copper} %%{pen4} %%{amdk7} %%{amdk8}

* Sat Oct 23 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-4m)
- cancel Patch2004 and Patch2005

* Sat Oct 23 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-3m)
- add Patch92: linux-2.6.9-swsusp-smp2.patch
- use %%if %%{buildup} at patch2004 and patch2005 for %%{buildsmp}

* Sat Oct 23 2004 Kazuhiro Yoshida <moriq@moriq.com>
- (2.6.9-2m)
- update swsusp2 (Source3090)
- update Patch530: linux-2.6.9-dbus.patch
- add Patch91: linux-2.6.9-swsusp-smp.patch
- add Patch2004: ipw2100-0.56-create_workqueue.patch
- add Patch2005: ipw2200-0.12-create_workqueue.patch

* Thu Oct 21 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.9-1m)
- version up to 2.6.9
- update Source135 to ipw2100-0.56.tgz
- update Source136 to ipw2200-0.12.tgz
- update Patch530: linux-2.6.9-dbus.patch

* Fri Oct 15 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.4m)
- move out %%global usagi_ipv6 1 from specopt
  in specopt usagi_ipv6 shall set always 0, why?
- update usagi patch to 2.6.9-rc4-20041013
- add print_specopt() from kernel24.spec

* Fri Oct 15 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.3m)
- change specopt intel CPUs kernel default 0,
  specific intel CPUs kernel will not build, build up and smp kernel only
- change apply swsusp2 patches (Source3090 and Patch90) buildup only
- delete SWSUSP2 setting from config-generic
- add SWSUSP2 setting from config-i586 and config-i686

* Fri Oct 15 2004 Shingo Akagaki <dora@kitty.dnsalias.org>
- (2.6.9-0.4.2m)
- update and enable ipw2100 driver.
- add ipw2200 driver.

* Mon Oct 11 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.4.1m)
- update to 2.6.9-rc4

* Mon Oct 11 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.4m)
- add Patch2000: scsi-qla2xxx-fix-inline-compile-errors.patch
- add Patch2001: linux-2.6.9-rc3-megaraid-gcc34.patch
- add Patch2002: scx200-undefine.patch
- cancel use gcc3.2, now use gcc3.4

* Sun Oct 10 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.3m)
- cancel Patch10000 and Patch10001
- add and comment out 'delete inline sed lines' for qla2xxx and megaraid
- use gcc3.2
- update usagi patch 2.6.9-rc3-20041009
- add Source3090 for swsusp2
- add Patch90 for swsusp2
- update Patch530: linux-2.6.9-rc3-dbus.patch for adapt swsusp2 patch
- update config-*
- update Makefile.configdefs

* Sat Oct 02 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.9-0.3.2m)
- add Patch10000: drivers-scsi-qla2xxx-gcc34.patch
- add Patch10001: drivers-scsi-megaraid-gcc34.patch

* Fri Oct  1 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.9-0.3.1m)
  update to 2.6.9-rc3
  removed mm patch, reiser4 unsupported

* Fri Sep 17 2004 Tsutomu Yasuda <tom@tom.homelinux.org>
- (2.6.8-15m)
  applied 2.6.8.1-mm4 patch(included reiser4 support).

* Thu Sep 16 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-14m)
- update spec to assign proper names for smp files [Momonga-devel.ja:02768]

* Sun Sep 12 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-13m)
- update usagi daily-snap date to 20040824 from 20040817
- add usagi_ipv6 as option for specopt and set 1 as default
- update ALSA driver to  version 1.0.7rc1
- add Patch1140: linux-2.6.8.1-usb2-storage.patch (reported by ryu)
  from http://www.mail-archive.com/linux-usb-devel@lists.sourceforge.net/msg27047.html

* Sun Sep 12 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-12m)
- add CPU specific kernel building options for Pentium4, Coppermine, AMD K7 and K8 CPUs.

* Sun Sep  5 2004 Shotaro Kamio <skamio@momonga-linux.org>
- (2.6.8-11m)
- add arch/x86_64/ to kernel-source (i586)
- add include/{media,mtd,rxrpc} to kernel-headers

* Fri Sep  3 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-10m)
- add Patch560: linux-2.6.8.1-crc-ccitt.patch

* Thu Sep  2 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-9m)
- change in config-generic
  CONFIG_APM=m                       [Momonga-devel.ja:02741] 
  CONFIG_APM_CPU_IDLE is not set     [Momonga-devel.ja:02741]
  CONFIG_APM_RTC_IS_GMT is not set   [Momonga-devel.ja:02741] 
  CONFIG_BLK_DEV_OFFBOARD=y          [Momonga-devel.ja:02741] 
  CONFIG_PPP_BSDCOMP=m

* Wed Sep  1 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-8m)
- change in config-generic
   CONFIG_USB_KBD=m
   CONFIG_USB_MOUSE=m
   CONFIG_REISERFS_CHECK is not set  [Momonga-devel.ja:02738] 

* Fri Aug 26 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-7m)
- change in config-generic (the following were not set)
    CONFIG_LEGACY_PTYS=y  [Momonga-users.ja:00139] 
    CONFIG_SCSI_DPT_I2O=m [Momonga-devel.ja:02732]

* Thu Aug 26 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-6m)
- add Patch1030: linux-2.6.8.1-ext3-reservations.patch
- add Patch1031: linux-2.6.8-ext3-reservations-update.patch
- add Patch1130: linux-2.6.7-i8x0-drm.patch
- remove /usr/src/linux-*/config-*
- disable kdb if specified in specopt

* Wed Aug 25 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.8-5m)
- revice config files

* Mon Aug 23 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-4m)
- merge some contents from kernel-2.6.8-i686.config by Fedora Core 
  to config-generic and config-x86-generic

* Sat Aug 21 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-3m)
- update alsa-driver to 1.0.6a
- added a forgotten link for asm-generic

* Tue Aug 17 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.8-2m)
- source version update to 2.6.8.1
- update alsa-driver to 1.0.6
- add Patch550: kernel2.6.8.1-kcalloc.patch

* Mon Aug  9 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.7-2m)
- update to alsa-1.0.6rc2
- update to hostap-driver-0.2.4 
- add libata driver
- update ieee1394 to 1233

* Sun Jun 20 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.7-1m)
- update to version 2.6.7
- update ieee1394 to 1228
- update to linux26-2.6.7-usagi-20040620
- edit Patch530 linux-2.6.7-dbus.patch from linux-2.6.5-dbus.patch
- remove Patch10000:  linux-2.6.6-compile.patch
- remove Patch10200:  linux-2.6.6-alsa-au88.patch
- clean up files no longer required to build

* Sun Jun 13 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-6m)
- edit Patch10000 linux-2.6.6-compile.patch from linux-2.6.1rc2-compile.patch
  not to remove EXPORT_SYMBOL(sys_close) from fs/open.c 

* Tue Jun  8 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-5m)
- update ALSA Driver 1.0.5a
- update hostap driver 0.2.2 
- add Patch10200 linux-2.6.6-alsa-au88.patch

* Mon Jun  7 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-4m)
- update to linux26-2.6.6-usagi-20040524
- update ieee1394 to 1222
- remove kernel26-CLEAR_BITMAP.patch

* Sun May 30 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-3m)
- add kernel26-CLEAR_BITMAP.patch

* Wed May 19 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-2m)
- update kdb files for kernel 2.6.6

* Tue May 18 2004 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.6.6-1m)
- version update to 2.6.6
- removed linux-2.6.5-usagi-fix.patch
- edited linux-2.6.6-online-resize.patch from linux-2.6.0-online-resize.patch

* Mon Apr 26 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-3m)
- changed to use modinfo.old to correct behavior with kernel 2.6.x

* Wed Apr 21 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-2m)
- add symlinks to header files

* Wed Apr 21 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.5-1m)
- update to 2.6.5

* Sun Apr  4 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-6m)
- kernel-drm shoule be provides so that we keep interoperability with FC.
- CONFIG_DVB_SP887X and CONFIG_SND_USB_AUDIO is not set due to avoid
  undefined symbol warning.

* Wed Mar 24 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-5m)
- revised spec for rpm 4.2
- set _unpackaged_files_terminate_build as 0, avoid remove each messy stuff.

* Thu Mar 23 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-4m)
- AKK stands for Anti-Kossori-Kossori.

* Sat Mar  5 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-4m)
- acpi patch is updated kossorily.

* Mon Mar  1 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.3-3m)
- acpi patch is updated to 20040220.

* Mon Feb 23 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.3-2m)
- revise config-*
- import KDB patch( to enable kdb, "echo '1' > /proc/sys/kernel/kdb")

* Thu Feb 19 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.3-1m)
- import hostap-driver-0.2.0
- update ALSA to 1.0.2c
- revise dbus patch for 2.6.3

* Tue Feb 17 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.6.2-2m)
- update ALSA to 1.0.2a

* Tue Feb 17 2004 Toru Hoshina <t@momonga-linux.org>
- (2.6.1-1m)
- up to 2.6.2.
- usagi patch was changed to 2004-02-10.
- acpi patch also up to 20040116.

* Thu Jan 15 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.1-1m)
- update to 2.6.1
- update usagi to 2.6.1-20040115

* Wed Jan  7 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.1-0.rc2.1m)
- update to 2.6.1rc2
  this release includes security fix
- update usagi to 20040106

* Sat Dec 20 2003 Kenta MURATA <muraken2@nifty.com>
- (2.6.0-0.3m)
- replace boot logo to momonga.
- append verbose_make option, default is 0.

* Thu Dec 18 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.6.0-0.2m)
- update acpipatch to 20031203-2.6.0
- fix cp Source10 to Source1

* Thu Dec 18 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.1m)
- update to 2.6.0

* Tue Dec 16 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.4m)
- update acpi to 20031203
- update cpufreq to 20031215
- kernel26-source: fix wrong dependency on kernel-headers
- fix typo in cpufreq (linux-2.6.0-fix-cpufreq-typo.patch)

* Mon Dec 15 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.3m)
- add usagi patch
- remove bk patch

* Mon Dec 15 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.2m)
- add Linus's bk patch
- restrict version of module-init-tools
- add kernel-headers sub package

* Sun Dec 14 2003 YAMAZAKI Makoto <zaki@zakky.org>
- (2.6.0-0.test11.1m)
- write spec
   based on momonga's kernel-2.4.23-4m and fedora's kernel-2.6.0-0.test11.1.13


## TODO
# unicon??
# bttv, saa7134
# madwifi
# delete alpha and ppc from basearch
